from a10sdk.common.A10BaseClass import A10BaseClass


class Host(A10BaseClass):
    
    """Class Description::
    IP Address of the local tunnel end point.

    Class host supports CRUD Operations and inherits from `common/A10BaseClass`.
    This class is the `"PARENT"` class for this module.`

    :param destination_vtep: {"optional": false, "type": "string", "description": "Configure the VTEP IP address (IPv4 address of the VTEP for the remote host)", "format": "ipv4-address"}
    :param ip_addr: {"optional": false, "type": "string", "description": "IPv4 address of the overlay host", "format": "ipv4-address"}
    :param vni: {"description": " Configure the segment id ( VNI of the remote host)", "format": "number", "type": "number", "maximum": 16777215, "minimum": 1, "optional": false}
    :param overlay_mac_addr: {"optional": false, "type": "string", "description": "MAC Address of the overlay host", "format": "mac-address"}
    :param DeviceProxy: The device proxy for REST operations and session handling. Refer to `common/device_proxy.py`

    

    URL for this object::
    `https://<Hostname|Ip address>//axapi/v3/overlay-tunnel/vtep/{id}/host/{ip_addr}+{overlay_mac_addr}+{vni}+{destination_vtep}`.

    

    
    """
    def __init__(self, **kwargs):
        self.ERROR_MSG = ""
        self.required = [ "ip_addr","overlay_mac_addr","vni","destination_vtep"]

        self.b_key = "host"
        self.a10_url="/axapi/v3/overlay-tunnel/vtep/{id}/host/{ip_addr}+{overlay_mac_addr}+{vni}+{destination_vtep}"
        self.DeviceProxy = ""
        self.destination_vtep = ""
        self.ip_addr = ""
        self.vni = ""
        self.overlay_mac_addr = ""

        for keys, value in kwargs.items():
            setattr(self,keys, value)





from a10sdk.common.A10BaseClass import A10BaseClass


class Stats(A10BaseClass):
    
    """This class does not support CRUD Operations please use parent.

    :param Krb_send_req_success: {"description": "Kerberos Request", "format": "counter", "type": "number", "oid": "1", "optional": true, "size": "8"}
    :param Ntlm_auth_success: {"description": "NTLM Authentication Success", "format": "counter", "type": "number", "oid": "11", "optional": true, "size": "8"}
    :param Ntlm_prepare_req_error: {"description": "NTLM Prepare Request Error", "format": "counter", "type": "number", "oid": "10", "optional": true, "size": "8"}
    :param Ntlm_other_error: {"description": "NTLM Other Error", "format": "counter", "type": "number", "oid": "14", "optional": true, "size": "8"}
    :param Ntlm_auth_failure: {"description": "NTLM Authentication Failure", "format": "counter", "type": "number", "oid": "12", "optional": true, "size": "8"}
    :param Krb_timeout_error: {"description": "Kerberos Timeout", "format": "counter", "type": "number", "oid": "3", "optional": true, "size": "8"}
    :param Ntlm_session_setup_success: {"description": "NTLM Session Setup Success", "format": "counter", "type": "number", "oid": "7", "optional": true, "size": "8"}
    :param Krb_other_error: {"description": "Kerberos Other Error", "format": "counter", "type": "number", "oid": "4", "optional": true, "size": "8"}
    :param Ntlm_proto_nego_failure: {"description": "NTLM Protocol Negotiation Failure", "format": "counter", "type": "number", "oid": "6", "optional": true, "size": "8"}
    :param Ntlm_session_setup_failure: {"description": "NTLM Session Setup Failure", "format": "counter", "type": "number", "oid": "8", "optional": true, "size": "8"}
    :param Ntlm_prepare_req_success: {"description": "NTLM Prepare Request Success", "format": "counter", "type": "number", "oid": "9", "optional": true, "size": "8"}
    :param Krb_get_resp_success: {"description": "Kerberos Response", "format": "counter", "type": "number", "oid": "2", "optional": true, "size": "8"}
    :param Ntlm_proto_nego_success: {"description": "NTLM Protocol Negotiation Success", "format": "counter", "type": "number", "oid": "5", "optional": true, "size": "8"}
    :param Ntlm_timeout_error: {"description": "NTLM Timeout", "format": "counter", "type": "number", "oid": "13", "optional": true, "size": "8"}
    :param DeviceProxy: The device proxy for REST operations and session handling. Refer to `common/device_proxy.py`

    

    
    """
    def __init__(self, **kwargs):
        self.ERROR_MSG = ""
        
        self.b_key = "stats"
        self.DeviceProxy = ""
        self.Krb_send_req_success = ""
        self.Ntlm_auth_success = ""
        self.Ntlm_prepare_req_error = ""
        self.Ntlm_other_error = ""
        self.Ntlm_auth_failure = ""
        self.Krb_timeout_error = ""
        self.Ntlm_session_setup_success = ""
        self.Krb_other_error = ""
        self.Ntlm_proto_nego_failure = ""
        self.Ntlm_session_setup_failure = ""
        self.Ntlm_prepare_req_success = ""
        self.Krb_get_resp_success = ""
        self.Ntlm_proto_nego_success = ""
        self.Ntlm_timeout_error = ""

        for keys, value in kwargs.items():
            setattr(self,keys, value)


class Instance(A10BaseClass):
    
    """Class Description::
    Statistics for the object instance.

    Class instance supports CRUD Operations and inherits from `common/A10BaseClass`.
    This class is the `"PARENT"` class for this module.`

    :param name: {"description": "Specify Windows authentication server name", "format": "string-rlx", "minLength": 1, "oid": "1001", "optional": false, "maxLength": 63, "type": "string"}
    :param DeviceProxy: The device proxy for REST operations and session handling. Refer to `common/device_proxy.py`

    

    URL for this object::
    `https://<Hostname|Ip address>//axapi/v3/aam/authentication/server/windows/instance/{name}/stats`.

    

    
    """
    def __init__(self, **kwargs):
        self.ERROR_MSG = ""
        self.required = [ "name"]

        self.b_key = "instance"
        self.a10_url="/axapi/v3/aam/authentication/server/windows/instance/{name}/stats"
        self.DeviceProxy = ""
        self.stats = {}
        self.name = ""

        for keys, value in kwargs.items():
            setattr(self,keys, value)





from a10sdk.common.A10BaseClass import A10BaseClass


class IcmpRateLimit(A10BaseClass):
    
    """Class Description::
    Limit the rate of ICMP packet.

    Class icmp-rate-limit supports CRUD Operations and inherits from `common/A10BaseClass`.
    This class is the `"PARENT"` class for this module.`

    :param icmp_normal_rate_limit: {"description": "Normal rate limit. If exceeds this limit, drop the ICMP packet that goes over the limit", "format": "number", "type": "number", "maximum": 65535, "minimum": 1, "optional": true}
    :param icmp_lockup: {"description": "Enter lockup state when ICMP rate exceeds lockup rate limit (Maximum rate limit. If exceeds this limit, drop all ICMP packet for a time period)", "format": "number", "type": "number", "maximum": 65535, "minimum": 1, "optional": true}
    :param icmp_lockup_period: {"description": "Lockup period (second)", "format": "number", "type": "number", "maximum": 16383, "minimum": 1, "optional": true}
    :param DeviceProxy: The device proxy for REST operations and session handling. Refer to `common/device_proxy.py`

    

    URL for this object::
    `https://<Hostname|Ip address>//axapi/v3/network/icmp-rate-limit`.

    

    
    """
    def __init__(self, **kwargs):
        self.ERROR_MSG = ""
        self.required=[]
        self.b_key = "icmp-rate-limit"
        self.a10_url="/axapi/v3/network/icmp-rate-limit"
        self.DeviceProxy = ""
        self.icmp_normal_rate_limit = ""
        self.icmp_lockup = ""
        self.icmp_lockup_period = ""

        for keys, value in kwargs.items():
            setattr(self,keys, value)





from a10sdk.common.A10BaseClass import A10BaseClass


class AdminSessionConnect(A10BaseClass):
    
    """    :param device: {"description": "Device (Device ID)", "format": "number", "type": "number", "maximum": 8, "minimum": 1, "optional": true}
    :param active_vrid: {"description": "VRRP vrid (Specify VRRP-A vrid)", "format": "number", "type": "number", "maximum": 31, "minimum": 0, "optional": true}
    :param DeviceProxy: The device proxy for REST operations and session handling. Refer to `common/device_proxy.py`

Class Description::
    Which target device to manage.

    Class admin-session-connect supports CRUD Operations and inherits from `common/A10BaseClass`.
    This class is the `"PARENT"` class for this module.`

    

    URL for this object::
    `https://<Hostname|Ip address>//axapi/v3/vcs/admin-session-connect`.

    

    
    """
    def __init__(self, **kwargs):
        self.ERROR_MSG = ""
        self.required=[]
        self.b_key = "admin-session-connect"
        self.a10_url="/axapi/v3/vcs/admin-session-connect"
        self.DeviceProxy = ""
        self.device = ""
        self.active_vrid = ""

        for keys, value in kwargs.items():
            setattr(self,keys, value)





from a10sdk.common.A10BaseClass import A10BaseClass


class TypeLast(A10BaseClass):
    
    """This class does not support CRUD Operations please use parent.

    :param last: {"minLength": 1, "maxLength": 63, "type": "string", "format": "string"}
    :param type: {"minLength": 1, "maxLength": 63, "type": "string", "format": "string"}
    :param DeviceProxy: The device proxy for REST operations and session handling. Refer to `common/device_proxy.py`

    

    
    """
    def __init__(self, **kwargs):
        self.ERROR_MSG = ""
        
        self.b_key = "type-last"
        self.DeviceProxy = ""
        self.last = ""
        self.A10WW_type = ""

        for keys, value in kwargs.items():
            setattr(self,keys, value)


class Oper(A10BaseClass):
    
    """This class does not support CRUD Operations please use parent.

    :param state: {"minLength": 1, "maxLength": 63, "type": "string", "format": "string"}
    :param type_last: {"minItems": 1, "items": {"type": "object"}, "uniqueItems": true, "type": "array", "array": [{"properties": {"last": {"minLength": 1, "maxLength": 63, "type": "string", "format": "string"}, "type": {"minLength": 1, "maxLength": 63, "type": "string", "format": "string"}, "optional": true}}]}
    :param gslb_site: {"minLength": 1, "maxLength": 63, "type": "string", "format": "string"}
    :param DeviceProxy: The device proxy for REST operations and session handling. Refer to `common/device_proxy.py`

    

    
    """
    def __init__(self, **kwargs):
        self.ERROR_MSG = ""
        
        self.b_key = "oper"
        self.DeviceProxy = ""
        self.state = ""
        self.type_last = []
        self.gslb_site = ""

        for keys, value in kwargs.items():
            setattr(self,keys, value)


class Site(A10BaseClass):
    
    """Class Description::
    Operational Status for the object site.

    Class site supports CRUD Operations and inherits from `common/A10BaseClass`.
    This class is the `"PARENT"` class for this module.`

    :param ip_server_list: {"minItems": 1, "items": {"type": "ip-server"}, "uniqueItems": true, "array": [{"required": ["ip-server-name"], "properties": {"oper": {"type": "object", "properties": {"state": {"minLength": 1, "maxLength": 63, "type": "string", "format": "string"}, "ip-server": {"minLength": 1, "maxLength": 63, "type": "string", "format": "string"}, "ip-server-port": {"minItems": 1, "items": {"type": "object"}, "uniqueItems": true, "type": "array", "array": [{"properties": {"optional": true, "vport": {"type": "number", "format": "number"}, "vport-state": {"minLength": 1, "maxLength": 63, "type": "string", "format": "string"}}}]}, "ip-address": {"minLength": 1, "maxLength": 63, "type": "string", "format": "string"}}}, "ip-server-name": {"description": "Specify the real server name", "format": "string", "minLength": 1, "oid": "1001", "optional": false, "maxLength": 63, "type": "string"}}}], "type": "array", "$ref": "/axapi/v3/gslb/site/{site-name}/ip-server/{ip-server-name}"}
    :param site_name: {"description": "Specify GSLB site name", "format": "string", "minLength": 1, "oid": "1001", "optional": false, "maxLength": 63, "type": "string"}
    :param slb_dev_list: {"minItems": 1, "items": {"type": "slb-dev"}, "uniqueItems": true, "array": [{"required": ["device-name"], "properties": {"oper": {"type": "object", "properties": {"dev_gw_state": {"minLength": 1, "maxLength": 63, "type": "string", "format": "string"}, "dev_attr": {"minLength": 1, "maxLength": 63, "type": "string", "format": "string"}, "dev_ip_cnt": {"type": "number", "format": "number"}, "dev_name": {"minLength": 1, "maxLength": 63, "type": "string", "format": "string"}, "dev_ip": {"minLength": 1, "maxLength": 63, "type": "string", "format": "string"}, "dev_session_num": {"type": "number", "format": "number"}, "dev_admin_preference": {"type": "number", "format": "number"}, "dev_session_util": {"type": "number", "format": "number"}}}, "device-name": {"description": "Specify SLB device name", "format": "string", "minLength": 1, "oid": "1001", "optional": false, "maxLength": 63, "type": "string"}, "vip-server": {"type": "object", "properties": {"oper": {"type": "object", "properties": {}}, "vip-server-v4-list": {"minItems": 1, "items": {"type": "vip-server-v4"}, "uniqueItems": true, "array": [{"required": ["ipv4"], "properties": {"oper": {"type": "object", "properties": {"dev_vip_addr": {"minLength": 1, "maxLength": 63, "type": "string", "format": "string"}, "dev_vip_state": {"minLength": 1, "maxLength": 63, "type": "string", "format": "string"}, "dev-vip-port-list": {"minItems": 1, "items": {"type": "object"}, "uniqueItems": true, "type": "array", "array": [{"properties": {"dev-vip-port-num": {"type": "number", "format": "number"}, "dev-vip-port-state": {"minLength": 1, "maxLength": 63, "type": "string", "format": "string"}, "optional": true}}]}}}, "ipv4": {"optional": false, "oid": "1001", "type": "string", "description": "Specify IP address", "format": "ipv4-address"}}}], "type": "array", "$ref": "/axapi/v3/gslb/site/{site-name}/ip-server/{ip-server-name}/slb-dev/{device-name}/vip-server/vip-server-v4/{ipv4}"}, "vip-server-v6-list": {"minItems": 1, "items": {"type": "vip-server-v6"}, "uniqueItems": true, "array": [{"required": ["ipv6"], "properties": {"oper": {"type": "object", "properties": {"dev_vip_addr": {"minLength": 1, "maxLength": 63, "type": "string", "format": "string"}, "dev_vip_state": {"minLength": 1, "maxLength": 63, "type": "string", "format": "string"}, "dev-vip-port-list": {"minItems": 1, "items": {"type": "object"}, "uniqueItems": true, "type": "array", "array": [{"properties": {"dev-vip-port-num": {"type": "number", "format": "number"}, "dev-vip-port-state": {"minLength": 1, "maxLength": 63, "type": "string", "format": "string"}, "optional": true}}]}}}, "ipv6": {"optional": false, "oid": "1001", "type": "string", "description": "Specify IP address (IPv6 address)", "format": "ipv6-address"}}}], "type": "array", "$ref": "/axapi/v3/gslb/site/{site-name}/ip-server/{ip-server-name}/slb-dev/{device-name}/vip-server/vip-server-v4/{ipv4}/vip-server-v6/{ipv6}"}, "vip-server-name-list": {"minItems": 1, "items": {"type": "vip-server-name"}, "uniqueItems": true, "array": [{"required": ["vip-name"], "properties": {"oper": {"type": "object", "properties": {"dev_vip_addr": {"minLength": 1, "maxLength": 63, "type": "string", "format": "string"}, "dev_vip_state": {"minLength": 1, "maxLength": 63, "type": "string", "format": "string"}, "dev-vip-port-list": {"minItems": 1, "items": {"type": "object"}, "uniqueItems": true, "type": "array", "array": [{"properties": {"dev-vip-port-num": {"type": "number", "format": "number"}, "dev-vip-port-state": {"minLength": 1, "maxLength": 63, "type": "string", "format": "string"}, "optional": true}}]}}}, "vip-name": {"description": "Specify a VIP name for the SLB device", "format": "string", "minLength": 1, "oid": "1001", "optional": false, "maxLength": 63, "type": "string"}}}], "type": "array", "$ref": "/axapi/v3/gslb/site/{site-name}/ip-server/{ip-server-name}/slb-dev/{device-name}/vip-server/vip-server-v4/{ipv4}/vip-server-v6/{ipv6}/vip-server-name/{vip-name}"}}}}}], "type": "array", "$ref": "/axapi/v3/gslb/site/{site-name}/ip-server/{ip-server-name}/slb-dev/{device-name}"}
    :param DeviceProxy: The device proxy for REST operations and session handling. Refer to `common/device_proxy.py`

    

    URL for this object::
    `https://<Hostname|Ip address>//axapi/v3/gslb/site/{site_name}/oper`.

    

    
    """
    def __init__(self, **kwargs):
        self.ERROR_MSG = ""
        self.required=[]
        self.b_key = "site"
        self.a10_url="/axapi/v3/gslb/site/{site_name}/oper"
        self.DeviceProxy = ""
        self.oper = {}
        self.ip_server_list = []
        self.site_name = ""
        self.slb_dev_list = []

        for keys, value in kwargs.items():
            setattr(self,keys, value)





from a10sdk.common.A10BaseClass import A10BaseClass


class Stats(A10BaseClass):
    
    """This class does not support CRUD Operations please use parent.

    :param inbound_icmp_packets_received: {"description": "Inbound ICMP packets received", "format": "counter", "type": "number", "oid": "10", "optional": true, "size": "2"}
    :param outbound_tcp_packets_received: {"description": "Outbound TCP packets received", "format": "counter", "type": "number", "oid": "1", "optional": true, "size": "2"}
    :param outbound_icmp_packets_received: {"description": "Outbound ICMP packets received", "format": "counter", "type": "number", "oid": "3", "optional": true, "size": "2"}
    :param vport_matched: {"description": "Traffic match SLB virtual port", "format": "counter", "type": "number", "oid": "16", "optional": true, "size": "2"}
    :param inbound_ipv4_dest_unreachable: {"description": "Inbound IPv4 destination unreachable", "format": "counter", "type": "number", "oid": "13", "optional": true, "size": "2"}
    :param not_local_ip: {"description": "Not local IP", "format": "counter", "type": "number", "oid": "19", "optional": true, "size": "2"}
    :param inbound_packets_drop: {"description": "Inbound packets dropped", "format": "counter", "type": "number", "oid": "12", "optional": true, "size": "2"}
    :param inbound_fragment_ipv4: {"description": "Inbound Fragmented IPv4", "format": "counter", "type": "number", "oid": "14", "optional": true, "size": "2"}
    :param fragment_error: {"description": "Fragment processing errors", "format": "counter", "type": "number", "oid": "20", "optional": true, "size": "2"}
    :param outbound_packets_drop: {"description": "Outbound packets dropped", "format": "counter", "type": "number", "oid": "5", "optional": true, "size": "2"}
    :param outbound_fragment_ipv6: {"description": "Outbound Fragmented IPv6", "format": "counter", "type": "number", "oid": "7", "optional": true, "size": "2"}
    :param outbound_ipv6_dest_unreachable: {"description": "Outbound IPv6 destination unreachable", "format": "counter", "type": "number", "oid": "6", "optional": true, "size": "2"}
    :param inbound_tunnel_fragment_ipv6: {"description": "Inbound Fragmented IPv6 in tunnel", "format": "counter", "type": "number", "oid": "15", "optional": true, "size": "2"}
    :param other_error: {"description": "Other errors", "format": "counter", "type": "number", "oid": "21", "optional": true, "size": "2"}
    :param outbound_udp_packets_received: {"description": "Outbound UDP packets received", "format": "counter", "type": "number", "oid": "2", "optional": true, "size": "2"}
    :param inbound_other_packets_received: {"description": "Inbound other packets received", "format": "counter", "type": "number", "oid": "11", "optional": true, "size": "2"}
    :param inbound_udp_packets_received: {"description": "Inbound UDP packets received", "format": "counter", "type": "number", "oid": "9", "optional": true, "size": "2"}
    :param outbound_other_packets_received: {"description": "Outbound other packets received", "format": "counter", "type": "number", "oid": "4", "optional": true, "size": "2"}
    :param packet_too_big: {"description": "Packet too big", "format": "counter", "type": "number", "oid": "18", "optional": true, "size": "2"}
    :param inbound_tcp_packets_received: {"description": "Inbound TCP packets received", "format": "counter", "type": "number", "oid": "8", "optional": true, "size": "2"}
    :param unknown_delegated_prefix: {"description": "Unknown 6rd delegated prefix", "format": "counter", "type": "number", "oid": "17", "optional": true, "size": "2"}
    :param DeviceProxy: The device proxy for REST operations and session handling. Refer to `common/device_proxy.py`

    

    
    """
    def __init__(self, **kwargs):
        self.ERROR_MSG = ""
        
        self.b_key = "stats"
        self.DeviceProxy = ""
        self.inbound_icmp_packets_received = ""
        self.outbound_tcp_packets_received = ""
        self.outbound_icmp_packets_received = ""
        self.vport_matched = ""
        self.inbound_ipv4_dest_unreachable = ""
        self.not_local_ip = ""
        self.inbound_packets_drop = ""
        self.inbound_fragment_ipv4 = ""
        self.fragment_error = ""
        self.outbound_packets_drop = ""
        self.outbound_fragment_ipv6 = ""
        self.outbound_ipv6_dest_unreachable = ""
        self.inbound_tunnel_fragment_ipv6 = ""
        self.other_error = ""
        self.outbound_udp_packets_received = ""
        self.inbound_other_packets_received = ""
        self.inbound_udp_packets_received = ""
        self.outbound_other_packets_received = ""
        self.packet_too_big = ""
        self.inbound_tcp_packets_received = ""
        self.unknown_delegated_prefix = ""

        for keys, value in kwargs.items():
            setattr(self,keys, value)


class Domain(A10BaseClass):
    
    """Class Description::
    Statistics for the object domain.

    Class domain supports CRUD Operations and inherits from `common/A10BaseClass`.
    This class is the `"PARENT"` class for this module.`

    :param name: {"description": "6rd Domain name", "format": "string", "minLength": 1, "oid": "1001", "optional": false, "maxLength": 63, "type": "string"}
    :param DeviceProxy: The device proxy for REST operations and session handling. Refer to `common/device_proxy.py`

    

    URL for this object::
    `https://<Hostname|Ip address>//axapi/v3/cgnv6/sixrd/domain/{name}/stats`.

    

    
    """
    def __init__(self, **kwargs):
        self.ERROR_MSG = ""
        self.required = [ "name"]

        self.b_key = "domain"
        self.a10_url="/axapi/v3/cgnv6/sixrd/domain/{name}/stats"
        self.DeviceProxy = ""
        self.stats = {}
        self.name = ""

        for keys, value in kwargs.items():
            setattr(self,keys, value)





from a10sdk.common.A10BaseClass import A10BaseClass


class TrunkMemberStatus(A10BaseClass):
    
    """This class does not support CRUD Operations please use parent.

    :param oper_status: {"enum": ["Blocked", "Up", "Dn"], "type": "string", "format": "enum"}
    :param cfg_status: {"enum": ["Enb", "Dis"], "type": "string", "format": "enum"}
    :param members: {"type": "number", "format": "number"}
    :param DeviceProxy: The device proxy for REST operations and session handling. Refer to `common/device_proxy.py`

    

    
    """
    def __init__(self, **kwargs):
        self.ERROR_MSG = ""
        
        self.b_key = "trunk-member-status"
        self.DeviceProxy = ""
        self.oper_status = ""
        self.cfg_status = ""
        self.members = ""

        for keys, value in kwargs.items():
            setattr(self,keys, value)


class Trunk(A10BaseClass):
    
    """This class does not support CRUD Operations please use parent.

    :param trunk_type: {"enum": ["Dynamic-LACP", "Static"], "type": "string", "format": "enum"}
    :param member_count: {"type": "number", "format": "number"}
    :param trunk_member_status: {"minItems": 1, "items": {"type": "object"}, "uniqueItems": true, "type": "array", "array": [{"properties": {"oper_status": {"enum": ["Blocked", "Up", "Dn"], "type": "string", "format": "enum"}, "optional": true, "cfg_status": {"enum": ["Enb", "Dis"], "type": "string", "format": "enum"}, "members": {"type": "number", "format": "number"}}}]}
    :param timer: {"type": "number", "format": "number"}
    :param trunk_status: {"enum": ["Up", "Down"], "type": "string", "format": "enum"}
    :param admin_key: {"type": "number", "format": "number"}
    :param timer_running: {"enum": ["Yes", "No"], "type": "string", "format": "enum"}
    :param ports_threshold: {"type": "number", "format": "number"}
    :param trunk_id: {"minimum": 1, "type": "number", "maximum": 16, "format": "number"}
    :param working_lead: {"type": "number", "format": "number"}
    :param DeviceProxy: The device proxy for REST operations and session handling. Refer to `common/device_proxy.py`

    

    
    """
    def __init__(self, **kwargs):
        self.ERROR_MSG = ""
        
        self.b_key = "trunk"
        self.DeviceProxy = ""
        self.trunk_type = ""
        self.member_count = ""
        self.trunk_member_status = []
        self.timer = ""
        self.trunk_status = ""
        self.admin_key = ""
        self.timer_running = ""
        self.ports_threshold = ""
        self.trunk_id = ""
        self.working_lead = ""

        for keys, value in kwargs.items():
            setattr(self,keys, value)


class Oper(A10BaseClass):
    
    """This class does not support CRUD Operations please use parent.

    :param trunk: {"minItems": 1, "items": {"type": "object"}, "uniqueItems": true, "type": "array", "array": [{"properties": {"trunk_type": {"enum": ["Dynamic-LACP", "Static"], "type": "string", "format": "enum"}, "member_count": {"type": "number", "format": "number"}, "trunk-member-status": {"minItems": 1, "items": {"type": "object"}, "uniqueItems": true, "type": "array", "array": [{"properties": {"oper_status": {"enum": ["Blocked", "Up", "Dn"], "type": "string", "format": "enum"}, "optional": true, "cfg_status": {"enum": ["Enb", "Dis"], "type": "string", "format": "enum"}, "members": {"type": "number", "format": "number"}}}]}, "timer": {"type": "number", "format": "number"}, "trunk_status": {"enum": ["Up", "Down"], "type": "string", "format": "enum"}, "admin_key": {"type": "number", "format": "number"}, "timer_running": {"enum": ["Yes", "No"], "type": "string", "format": "enum"}, "ports_threshold": {"type": "number", "format": "number"}, "trunk_id": {"minimum": 1, "type": "number", "maximum": 16, "format": "number"}, "optional": true, "working_lead": {"type": "number", "format": "number"}}}]}
    :param DeviceProxy: The device proxy for REST operations and session handling. Refer to `common/device_proxy.py`

    

    
    """
    def __init__(self, **kwargs):
        self.ERROR_MSG = ""
        
        self.b_key = "oper"
        self.DeviceProxy = ""
        self.trunk = []

        for keys, value in kwargs.items():
            setattr(self,keys, value)


class Trunk(A10BaseClass):
    
    """Class Description::
    Operational Status for the object trunk.

    Class trunk supports CRUD Operations and inherits from `common/A10BaseClass`.
    This class is the `"PARENT"` class for this module.`

    :param DeviceProxy: The device proxy for REST operations and session handling. Refer to `common/device_proxy.py`

    

    URL for this object::
    `https://<Hostname|Ip address>//axapi/v3/network/trunk/oper`.

    

    
    """
    def __init__(self, **kwargs):
        self.ERROR_MSG = ""
        self.required=[]
        self.b_key = "trunk"
        self.a10_url="/axapi/v3/network/trunk/oper"
        self.DeviceProxy = ""
        self.oper = {}

        for keys, value in kwargs.items():
            setattr(self,keys, value)





from a10sdk.common.A10BaseClass import A10BaseClass


class EmailList(A10BaseClass):
    
    """This class does not support CRUD Operations please use parent.

    :param email_address: {"minLength": 1, "maxLength": 63, "type": "string", "description": "Email address information of recipients", "format": "email-addr"}
    :param DeviceProxy: The device proxy for REST operations and session handling. Refer to `common/device_proxy.py`

    

    
    """
    def __init__(self, **kwargs):
        self.ERROR_MSG = ""
        
        self.b_key = "email-list"
        self.DeviceProxy = ""
        self.email_address = ""

        for keys, value in kwargs.items():
            setattr(self,keys, value)


class EmailAddress(A10BaseClass):
    
    """Class Description::
    Set the recipients address.

    Class email-address supports CRUD Operations and inherits from `common/A10BaseClass`.
    This class is the `"PARENT"` class for this module.`

    :param email_list: {"minItems": 1, "items": {"type": "object"}, "uniqueItems": true, "type": "array", "array": [{"properties": {"email-address": {"minLength": 1, "maxLength": 63, "type": "string", "description": "Email address information of recipients", "format": "email-addr"}, "optional": true}}]}
    :param DeviceProxy: The device proxy for REST operations and session handling. Refer to `common/device_proxy.py`

    

    URL for this object::
    `https://<Hostname|Ip address>//axapi/v3/logging/email-address`.

    

    
    """
    def __init__(self, **kwargs):
        self.ERROR_MSG = ""
        self.required=[]
        self.b_key = "email-address"
        self.a10_url="/axapi/v3/logging/email-address"
        self.DeviceProxy = ""
        self.email_list = []

        for keys, value in kwargs.items():
            setattr(self,keys, value)





from a10sdk.common.A10BaseClass import A10BaseClass


class Locale(A10BaseClass):
    
    """Class Description::
    Set locale for the CLI startup.

    Class locale supports CRUD Operations and inherits from `common/A10BaseClass`.
    This class is the `"PARENT"` class for this module.`

    :param value: {"description": "'en_US.UTF-8': English locale for the USA, encoding with UTF-8 (default); 'zh_CN.UTF-8': Chinese locale for PRC, encoding with UTF-8; 'zh_CN.GB18030': Chinese locale for PRC, encoding with GB18030; 'zh_CN.GBK': Chinese locale for PRC, encoding with GBK; 'zh_CN.GB2312': Chinese locale for PRC, encoding with GB2312; 'zh_TW.UTF-8': Chinese locale for Taiwan, encoding with UTF-8; 'zh_TW.BIG5': Chinese locale for Taiwan, encoding with BIG5; 'zh_TW.EUCTW': Chinese locale for Taiwan, encoding with EUC-TW; 'ja_JP.UTF-8': Japanese locale for Japan, encoding with UTF-8; 'ja_JP.EUC-JP': Japanese locale for Japan, encoding with EUC-JP; ", "format": "enum", "default": "en_US.UTF-8", "type": "string", "enum": ["en_US.UTF-8", "zh_CN.UTF-8", "zh_CN.GB18030", "zh_CN.GBK", "zh_CN.GB2312", "zh_TW.UTF-8", "zh_TW.BIG5", "zh_TW.EUCTW", "ja_JP.UTF-8", "ja_JP.EUC-JP"], "optional": true}
    :param DeviceProxy: The device proxy for REST operations and session handling. Refer to `common/device_proxy.py`

    

    URL for this object::
    `https://<Hostname|Ip address>//axapi/v3/locale`.

    

    
    """
    def __init__(self, **kwargs):
        self.ERROR_MSG = ""
        self.required=[]
        self.b_key = "locale"
        self.a10_url="/axapi/v3/locale"
        self.DeviceProxy = ""
        self.test = {}
        self.value = ""

        for keys, value in kwargs.items():
            setattr(self,keys, value)





from a10sdk.common.A10BaseClass import A10BaseClass


class Database(A10BaseClass):
    
    """Class Description::
    DATABASE type.

    Class database supports CRUD Operations and inherits from `common/A10BaseClass`.
    This class is the `"PARENT"` class for this module.`

    :param db_send: {"description": "Specify the SQL query", "format": "string-rlx", "minLength": 1, "optional": true, "maxLength": 63, "type": "string"}
    :param db_password: {"default": 0, "optional": true, "type": "number", "description": "Specify the user password", "format": "flag"}
    :param database: {"default": 0, "optional": true, "type": "number", "description": "DATABASE type", "format": "flag"}
    :param db_receive: {"description": "Specify the response string", "format": "string-rlx", "minLength": 1, "optional": true, "maxLength": 31, "type": "string"}
    :param database_name: {"optional": true, "enum": ["mssql", "mysql", "oracle", "postgresql"], "type": "string", "description": "'mssql': Specify MSSQL database; 'mysql': Specify MySQL database; 'oracle': Specify Oracle database; 'postgresql': Specify PostgreSQL database; ", "format": "enum"}
    :param db_password_str: {"description": "Configure password", "format": "password", "minLength": 1, "optional": true, "maxLength": 31, "type": "string"}
    :param db_encrypted: {"optional": true, "type": "encrypted", "description": "Do NOT use this option manually. (This is an A10 reserved keyword.) (The ENCRYPTED password string)", "format": "encrypted"}
    :param db_column: {"description": "Specify the column number for receiving", "format": "number", "type": "number", "maximum": 10, "minimum": 1, "optional": true}
    :param db_name: {"description": "Specify the database name", "format": "string-rlx", "minLength": 1, "optional": true, "maxLength": 31, "type": "string"}
    :param db_username: {"description": "Specify the username", "format": "string-rlx", "minLength": 1, "optional": true, "maxLength": 31, "type": "string"}
    :param db_row: {"description": "Specify the row number for receiving", "format": "number", "type": "number", "maximum": 10, "minimum": 1, "optional": true}
    :param DeviceProxy: The device proxy for REST operations and session handling. Refer to `common/device_proxy.py`

    

    URL for this object::
    `https://<Hostname|Ip address>//axapi/v3/health/monitor/{name}/method/database`.

    

    
    """
    def __init__(self, **kwargs):
        self.ERROR_MSG = ""
        self.required=[]
        self.b_key = "database"
        self.a10_url="/axapi/v3/health/monitor/{name}/method/database"
        self.DeviceProxy = ""
        self.db_send = ""
        self.db_password = ""
        self.database = ""
        self.db_receive = ""
        self.database_name = ""
        self.db_password_str = ""
        self.db_encrypted = ""
        self.db_column = ""
        self.db_name = ""
        self.db_username = ""
        self.db_row = ""

        for keys, value in kwargs.items():
            setattr(self,keys, value)





from a10sdk.common.A10BaseClass import A10BaseClass


class Severity(A10BaseClass):
    
    """This class does not support CRUD Operations please use parent.

    :param severity_string: {"description": "'emergency': 0: Emergency; 'alert': 1: Alert; 'critical': 2: Critical; 'error': 3: Error; 'warning': 4: Warning; 'notice': 5: Notice; 'informational': 6: Informational; 'debug': 7: Debug; ", "format": "enum", "default": "debug", "enum": ["emergency", "alert", "critical", "error", "warning", "notice", "informational", "debug"], "not": "severity-val", "type": "string"}
    :param severity_val: {"description": "Logging severity level", "format": "number", "default": 7, "maximum": 7, "minimum": 0, "not": "severity-string", "type": "number"}
    :param DeviceProxy: The device proxy for REST operations and session handling. Refer to `common/device_proxy.py`

    

    
    """
    def __init__(self, **kwargs):
        self.ERROR_MSG = ""
        
        self.b_key = "severity"
        self.DeviceProxy = ""
        self.severity_string = ""
        self.severity_val = ""

        for keys, value in kwargs.items():
            setattr(self,keys, value)


class Log(A10BaseClass):
    
    """This class does not support CRUD Operations please use parent.

    :param port_mappings: {"enum": ["creation", "disable"], "type": "string", "description": "'creation': Log creation of NAT mappgins; 'disable': Disable Log creation and deletion of NAT mappings; ", "format": "enum"}
    :param DeviceProxy: The device proxy for REST operations and session handling. Refer to `common/device_proxy.py`

    

    
    """
    def __init__(self, **kwargs):
        self.ERROR_MSG = ""
        
        self.b_key = "log"
        self.DeviceProxy = ""
        self.port_mappings = ""

        for keys, value in kwargs.items():
            setattr(self,keys, value)


class SourcePort(A10BaseClass):
    
    """This class does not support CRUD Operations please use parent.

    :param source_port_num: {"description": "Set source port for sending NAT syslogs (default: 514)", "format": "number", "default": 514, "maximum": 65535, "minimum": 1, "not": "any", "type": "number"}
    :param any: {"default": 0, "not": "source-port-num", "type": "number", "description": "Use any source port", "format": "flag"}
    :param DeviceProxy: The device proxy for REST operations and session handling. Refer to `common/device_proxy.py`

    

    
    """
    def __init__(self, **kwargs):
        self.ERROR_MSG = ""
        
        self.b_key = "source-port"
        self.DeviceProxy = ""
        self.source_port_num = ""
        self.A10WW_any = ""

        for keys, value in kwargs.items():
            setattr(self,keys, value)


class Logging(A10BaseClass):
    
    """Class Description::
    NAT Logging Template.

    Class logging supports CRUD Operations and inherits from `common/A10BaseClass`.
    This class is the `"PARENT"` class for this module.`

    :param facility: {"description": "'kernel': 0: Kernel; 'user': 1: User-level; 'mail': 2: Mail; 'daemon': 3: System daemons; 'security-authorization': 4: Security/authorization; 'syslog': 5: Syslog internal; 'line-printer': 6: Line printer; 'news': 7: Network news; 'uucp': 8: UUCP subsystem; 'cron': 9: Time-related; 'security-authorization-private': 10: Private security/authorization; 'ftp': 11: FTP; 'ntp': 12: NTP; 'audit': 13: Audit; 'alert': 14: Alert; 'clock': 15: Clock-related; 'local0': 16: Local use 0; 'local1': 17: Local use 1; 'local2': 18: Local use 2; 'local3': 19: Local use 3; 'local4': 20: Local use 4; 'local5': 21: Local use 5; 'local6': 22: Local use 6; 'local7': 23: Local use 7; ", "format": "enum", "default": "local0", "type": "string", "enum": ["kernel", "user", "mail", "daemon", "security-authorization", "syslog", "line-printer", "news", "uucp", "cron", "security-authorization-private", "ftp", "ntp", "audit", "alert", "clock", "local0", "local1", "local2", "local3", "local4", "local5", "local6", "local7"], "optional": true}
    :param include_destination: {"default": 0, "optional": true, "type": "number", "description": "Include the destination IP and port in logs", "format": "flag"}
    :param service_group: {"description": "Set NAT logging service-group", "format": "string-rlx", "minLength": 1, "optional": true, "maxLength": 63, "type": "string", "$ref": "/axapi/v3/slb/service-group"}
    :param include_rip_rport: {"default": 0, "optional": true, "type": "number", "description": "Include the IP and port of real server in logs", "format": "flag"}
    :param name: {"description": "NAT logging template name", "format": "string-rlx", "minLength": 1, "optional": false, "maxLength": 63, "type": "string"}
    :param DeviceProxy: The device proxy for REST operations and session handling. Refer to `common/device_proxy.py`

    

    URL for this object::
    `https://<Hostname|Ip address>//axapi/v3/ip/nat/template/logging/{name}`.

    

    
    """
    def __init__(self, **kwargs):
        self.ERROR_MSG = ""
        self.required = [ "name"]

        self.b_key = "logging"
        self.a10_url="/axapi/v3/ip/nat/template/logging/{name}"
        self.DeviceProxy = ""
        self.severity = {}
        self.facility = ""
        self.include_destination = ""
        self.service_group = ""
        self.log = {}
        self.source_port = {}
        self.include_rip_rport = ""
        self.name = ""

        for keys, value in kwargs.items():
            setattr(self,keys, value)





from a10sdk.common.A10BaseClass import A10BaseClass


class VirtualLinkList(A10BaseClass):
    
    """This class does not support CRUD Operations please use parent.

    :param dead_interval: {"description": "Dead router detection time (Seconds)", "minimum": 1, "type": "number", "maximum": 65535, "format": "number"}
    :param hello_interval: {"description": "Hello packet interval (Seconds)", "minimum": 1, "type": "number", "maximum": 65535, "format": "number"}
    :param bfd: {"default": 0, "type": "number", "description": "Bidirectional Forwarding Detection (BFD)", "format": "flag"}
    :param transmit_delay: {"description": "LSA transmission delay (Seconds)", "format": "number", "default": 1, "maximum": 3600, "minimum": 1, "type": "number"}
    :param value: {"type": "string", "description": "ID (IP addr) associated with virtual link neighbor", "format": "ipv4-address"}
    :param retransmit_interval: {"description": "LSA retransmit interval (Seconds)", "minimum": 1, "type": "number", "maximum": 3600, "format": "number"}
    :param instance_id: {"description": "OSPFv3 instance ID", "format": "number", "default": 0, "maximum": 255, "minimum": 0, "type": "number"}
    :param DeviceProxy: The device proxy for REST operations and session handling. Refer to `common/device_proxy.py`

    

    
    """
    def __init__(self, **kwargs):
        self.ERROR_MSG = ""
        
        self.b_key = "virtual-link-list"
        self.DeviceProxy = ""
        self.dead_interval = ""
        self.hello_interval = ""
        self.bfd = ""
        self.transmit_delay = ""
        self.value = ""
        self.retransmit_interval = ""
        self.instance_id = ""

        for keys, value in kwargs.items():
            setattr(self,keys, value)


class RangeList(A10BaseClass):
    
    """This class does not support CRUD Operations please use parent.

    :param option: {"enum": ["advertise", "not-advertise"], "type": "string", "description": "'advertise': Advertise this range (default); 'not-advertise': DoNotAdvertise this range; ", "format": "enum"}
    :param value: {"type": "string", "description": "Area range for IPv6 prefix", "format": "ipv6-address-plen"}
    :param DeviceProxy: The device proxy for REST operations and session handling. Refer to `common/device_proxy.py`

    

    
    """
    def __init__(self, **kwargs):
        self.ERROR_MSG = ""
        
        self.b_key = "range-list"
        self.DeviceProxy = ""
        self.option = ""
        self.value = ""

        for keys, value in kwargs.items():
            setattr(self,keys, value)


class Area(A10BaseClass):
    
    """Class Description::
    OSPF area parameters.

    Class area supports CRUD Operations and inherits from `common/A10BaseClass`.
    This class is the `"PARENT"` class for this module.`

    :param area_ipv4: {"optional": false, "type": "string", "description": "OSPFv3 area ID in IP address format", "format": "ipv4-address"}
    :param virtual_link_list: {"minItems": 1, "items": {"type": "object"}, "uniqueItems": true, "type": "array", "array": [{"properties": {"dead-interval": {"description": "Dead router detection time (Seconds)", "minimum": 1, "type": "number", "maximum": 65535, "format": "number"}, "hello-interval": {"description": "Hello packet interval (Seconds)", "minimum": 1, "type": "number", "maximum": 65535, "format": "number"}, "bfd": {"default": 0, "type": "number", "description": "Bidirectional Forwarding Detection (BFD)", "format": "flag"}, "transmit-delay": {"description": "LSA transmission delay (Seconds)", "format": "number", "default": 1, "maximum": 3600, "minimum": 1, "type": "number"}, "value": {"type": "string", "description": "ID (IP addr) associated with virtual link neighbor", "format": "ipv4-address"}, "retransmit-interval": {"description": "LSA retransmit interval (Seconds)", "minimum": 1, "type": "number", "maximum": 3600, "format": "number"}, "optional": true, "instance-id": {"description": "OSPFv3 instance ID", "format": "number", "default": 0, "maximum": 255, "minimum": 0, "type": "number"}}}]}
    :param no_summary: {"default": 0, "optional": true, "type": "number", "description": "Do not inject inter-area routes into area", "format": "flag"}
    :param stub: {"default": 0, "optional": true, "type": "number", "description": "Configure OSPFv3 area as stub", "format": "flag"}
    :param range_list: {"minItems": 1, "items": {"type": "object"}, "uniqueItems": true, "type": "array", "array": [{"properties": {"optional": true, "option": {"enum": ["advertise", "not-advertise"], "type": "string", "description": "'advertise': Advertise this range (default); 'not-advertise': DoNotAdvertise this range; ", "format": "enum"}, "value": {"type": "string", "description": "Area range for IPv6 prefix", "format": "ipv6-address-plen"}}}]}
    :param default_cost: {"description": "Set the summary-default cost of a NSSA or stub area (Stub's advertised default summary cost)", "format": "number", "default": 1, "optional": true, "maximum": 16777215, "minimum": 0, "type": "number"}
    :param area_num: {"description": "OSPFv3 area ID as a decimal value", "format": "number", "type": "number", "maximum": 4294967295, "minimum": 0, "optional": false}
    :param DeviceProxy: The device proxy for REST operations and session handling. Refer to `common/device_proxy.py`

    

    URL for this object::
    `https://<Hostname|Ip address>//axapi/v3/router/ipv6/ospf/{process_id}/area/{area_ipv4}+{area_num}`.

    

    
    """
    def __init__(self, **kwargs):
        self.ERROR_MSG = ""
        self.required = [ "area_ipv4","area_num"]

        self.b_key = "area"
        self.a10_url="/axapi/v3/router/ipv6/ospf/{process_id}/area/{area_ipv4}+{area_num}"
        self.DeviceProxy = ""
        self.area_ipv4 = ""
        self.virtual_link_list = []
        self.no_summary = ""
        self.stub = ""
        self.range_list = []
        self.default_cost = ""
        self.area_num = ""

        for keys, value in kwargs.items():
            setattr(self,keys, value)





from a10sdk.common.A10BaseClass import A10BaseClass


class SplitHorizonCfg(A10BaseClass):
    
    """This class does not support CRUD Operations please use parent.

    :param state: {"default": "poisoned", "enum": ["poisoned", "disable", "enable"], "type": "string", "description": "'poisoned': Perform split horizon with poisoned reverse; 'disable': Disable split horizon; 'enable': Perform split horizon without poisoned reverse; ", "format": "enum"}
    :param DeviceProxy: The device proxy for REST operations and session handling. Refer to `common/device_proxy.py`

    

    
    """
    def __init__(self, **kwargs):
        self.ERROR_MSG = ""
        
        self.b_key = "split-horizon-cfg"
        self.DeviceProxy = ""
        self.state = ""

        for keys, value in kwargs.items():
            setattr(self,keys, value)


class Rip(A10BaseClass):
    
    """Class Description::
    RIP.

    Class rip supports CRUD Operations and inherits from `common/A10BaseClass`.
    This class is the `"PARENT"` class for this module.`

    :param DeviceProxy: The device proxy for REST operations and session handling. Refer to `common/device_proxy.py`

    

    URL for this object::
    `https://<Hostname|Ip address>//axapi/v3/interface/loopback/{ifnum}/ipv6/rip`.

    

    
    """
    def __init__(self, **kwargs):
        self.ERROR_MSG = ""
        self.required=[]
        self.b_key = "rip"
        self.a10_url="/axapi/v3/interface/loopback/{ifnum}/ipv6/rip"
        self.DeviceProxy = ""
        self.split_horizon_cfg = {}

        for keys, value in kwargs.items():
            setattr(self,keys, value)





from a10sdk.common.A10BaseClass import A10BaseClass


class IpLists(A10BaseClass):
    
    """This class does not support CRUD Operations please use parent.

    :param listname: {"minLength": 1, "maxLength": 63, "type": "string", "format": "string"}
    :param hits: {"type": "number", "format": "number"}
    :param errors: {"type": "number", "format": "number"}
    :param last: {"minLength": 1, "maxLength": 63, "type": "string", "format": "string"}
    :param total_entries_in_list: {"type": "number", "format": "number"}
    :param ipaddr: {"minLength": 1, "maxLength": 63, "type": "string", "format": "string"}
    :param filename: {"minLength": 1, "maxLength": 63, "type": "string", "format": "string"}
    :param file_lines: {"type": "number", "format": "number"}
    :param ipaddr_filter: {"type": "number", "format": "number"}
    :param ipmask: {"minLength": 1, "maxLength": 63, "type": "string", "format": "string"}
    :param type: {"enum": ["manual", "file"], "type": "string", "format": "enum"}
    :param group_id: {"type": "number", "format": "number"}
    :param DeviceProxy: The device proxy for REST operations and session handling. Refer to `common/device_proxy.py`

    

    
    """
    def __init__(self, **kwargs):
        self.ERROR_MSG = ""
        
        self.b_key = "ip-lists"
        self.DeviceProxy = ""
        self.listname = ""
        self.hits = ""
        self.errors = ""
        self.last = ""
        self.total_entries_in_list = ""
        self.ipaddr = ""
        self.filename = ""
        self.file_lines = ""
        self.ipaddr_filter = ""
        self.ipmask = ""
        self.A10WW_type = ""
        self.group_id = ""

        for keys, value in kwargs.items():
            setattr(self,keys, value)


class Oper(A10BaseClass):
    
    """This class does not support CRUD Operations please use parent.

    :param ip_lists: {"minItems": 1, "items": {"type": "object"}, "uniqueItems": true, "type": "array", "array": [{"properties": {"listname": {"minLength": 1, "maxLength": 63, "type": "string", "format": "string"}, "hits": {"type": "number", "format": "number"}, "errors": {"type": "number", "format": "number"}, "last": {"minLength": 1, "maxLength": 63, "type": "string", "format": "string"}, "total-entries-in-list": {"type": "number", "format": "number"}, "optional": true, "ipaddr": {"minLength": 1, "maxLength": 63, "type": "string", "format": "string"}, "filename": {"minLength": 1, "maxLength": 63, "type": "string", "format": "string"}, "file-lines": {"type": "number", "format": "number"}, "ipaddr-filter": {"type": "number", "format": "number"}, "ipmask": {"minLength": 1, "maxLength": 63, "type": "string", "format": "string"}, "type": {"enum": ["manual", "file"], "type": "string", "format": "enum"}, "group-id": {"type": "number", "format": "number"}}}]}
    :param DeviceProxy: The device proxy for REST operations and session handling. Refer to `common/device_proxy.py`

    

    
    """
    def __init__(self, **kwargs):
        self.ERROR_MSG = ""
        
        self.b_key = "oper"
        self.DeviceProxy = ""
        self.ip_lists = []

        for keys, value in kwargs.items():
            setattr(self,keys, value)


class IpListInfo(A10BaseClass):
    
    """Class Description::
    Operational Status for the object ip-list-info.

    Class ip-list-info supports CRUD Operations and inherits from `common/A10BaseClass`.
    This class is the `"PARENT"` class for this module.`

    :param DeviceProxy: The device proxy for REST operations and session handling. Refer to `common/device_proxy.py`

    

    URL for this object::
    `https://<Hostname|Ip address>//axapi/v3/gslb/ip-list-info/oper`.

    

    
    """
    def __init__(self, **kwargs):
        self.ERROR_MSG = ""
        self.required=[]
        self.b_key = "ip-list-info"
        self.a10_url="/axapi/v3/gslb/ip-list-info/oper"
        self.DeviceProxy = ""
        self.oper = {}

        for keys, value in kwargs.items():
            setattr(self,keys, value)





from a10sdk.common.A10BaseClass import A10BaseClass


class System(A10BaseClass):
    
    """Class Description::
    Configure System Parameters.

    Class system supports CRUD Operations and inherits from `common/A10BaseClass`.
    This class is the `"PARENT"` class for this module.`

    :param promiscuous_mode: {"description": "Run in promiscous mode settings", "format": "flag", "default": 0, "type": "number", "plat-pos-list": ["soft-ax"], "optional": true}
    :param glid: {"description": "Apply limits to the whole system", "format": "number", "optional": true, "maximum": 1023, "minimum": 1, "type": "number", "$ref": "/axapi/v3/glid"}
    :param template_policy: {"description": "Apply policy template to the whole system (Policy template name)", "format": "string", "minLength": 1, "optional": true, "maxLength": 63, "type": "string", "$ref": "/axapi/v3/slb/template/policy"}
    :param ddos_log: {"default": 0, "optional": true, "type": "number", "description": "log DDoS attack anomalies", "format": "flag"}
    :param ddos_attack: {"default": 0, "optional": true, "type": "number", "description": "System DDoS Attack", "format": "flag"}
    :param module_ctrl_cpu: {"optional": true, "enum": ["high", "low", "medium"], "type": "string", "description": "'high': high cpu usage; 'low': low cpu usage; 'medium': medium cpu usage; ", "format": "enum"}
    :param attack: {"default": 0, "optional": true, "type": "number", "description": "System Attack", "format": "flag"}
    :param template_monitor: {"description": "Apply monitor template to the whole system (Monitor template ID Number)", "format": "number", "optional": true, "maximum": 16, "minimum": 1, "type": "number", "$ref": "/axapi/v3/slb/template/monitor"}
    :param log_cpu_interval: {"description": "Log high CPU interval (Specify consecutive seconds before logging high CPU)", "format": "number", "type": "number", "maximum": 255, "minimum": 15, "optional": true}
    :param anomaly_log: {"default": 0, "optional": true, "type": "number", "description": "log system anomalies", "format": "flag"}
    :param attack_log: {"default": 0, "optional": true, "type": "number", "description": "log attack anomalies", "format": "flag"}
    :param DeviceProxy: The device proxy for REST operations and session handling. Refer to `common/device_proxy.py`

    

    URL for this object::
    `https://<Hostname|Ip address>//axapi/v3/system`.

    

    
    """
    def __init__(self, **kwargs):
        self.ERROR_MSG = ""
        self.required=[]
        self.b_key = "system"
        self.a10_url="/axapi/v3/system"
        self.DeviceProxy = ""
        self.resource_usage = {}
        self.cpu_load_sharing = {}
        self.promiscuous_mode = ""
        self.per_vlan_limit = {}
        self.glid = ""
        self.all_vlan_limit = {}
        self.template_policy = ""
        self.ddos_log = ""
        self.ddos_attack = ""
        self.module_ctrl_cpu = ""
        self.attack = ""
        self.template_monitor = ""
        self.ve_mac_scheme = {}
        self.log_cpu_interval = ""
        self.anomaly_log = ""
        self.attack_log = ""
        self.ipsec = {}

        for keys, value in kwargs.items():
            setattr(self,keys, value)





from a10sdk.common.A10BaseClass import A10BaseClass


class Dnssec(A10BaseClass):
    
    """Class Description::
    Domain Name System Security Extensions commands.

    Class dnssec supports CRUD Operations and inherits from `common/A10BaseClass`.
    This class is the `"PARENT"` class for this module.`

    :param standalone: {"default": 0, "optional": true, "type": "number", "description": "Run DNSSEC in standalone mode, in GSLB group mode by default", "format": "flag"}
    :param template_list: {"minItems": 1, "items": {"type": "template"}, "uniqueItems": true, "array": [{"required": ["dnssec-temp-name"], "properties": {"dnssec-template-ksk": {"type": "object", "properties": {"ksk-keysize-k": {"default": 0, "type": "number", "description": "Specify the number of bits in the DNSSEC KSK keys", "format": "flag"}, "zsk-rollover-time-v": {"description": "7 days less than the lifetime by default", "format": "number", "default": 358, "maximum": 3650, "minimum": 1, "type": "number"}, "ksk-lifetime-v": {"description": "Default value is 365 days", "minimum": 2, "type": "number", "maximum": 3650, "format": "number"}, "ksk-keysize-v": {"description": "Default size is 2048 and must be an exact multiple of 64", "minimum": 1024, "type": "number", "maximum": 4096, "format": "number"}, "ksk-rollover-time-k": {"default": 0, "type": "number", "description": "Set the rollover time in days", "format": "flag"}, "ksk-lifetime-k": {"default": 0, "type": "number", "description": "Set the lifetime for DNSSEC KSK keys in days", "format": "flag"}}}, "algorithm": {"optional": true, "enum": ["RSASHA1", "RSASHA256", "RSASHA512"], "type": "string", "description": "'RSASHA1': RSASHA1 algorithm; 'RSASHA256': RSASHA256 algorithm; 'RSASHA512': RSASHA512 algorithm; ", "format": "enum"}, "combinations-limit": {"description": "the max number of combinations per RRset (Default value is 31)", "format": "number", "type": "number", "maximum": 65535, "minimum": 1, "optional": true}, "dnskey-ttl-k": {"default": 0, "optional": true, "type": "number", "description": "The TTL value of DNSKEY RR", "format": "flag"}, "signature-validity-period-k": {"default": 0, "optional": true, "type": "number", "description": "The period that a signature is valid", "format": "flag"}, "hsm": {"description": "specify the HSM template", "format": "string", "minLength": 1, "optional": true, "maxLength": 63, "type": "string", "$ref": "/axapi/v3/hsm/template"}, "enable-nsec3": {"default": 0, "optional": true, "type": "number", "description": "enable NSEC3 support. disabled by default", "format": "flag"}, "return-nsec-on-failure": {"default": 1, "optional": true, "type": "number", "description": "return NSEC/NSEC3 or not on failure case. return by default", "format": "flag"}, "dnskey-ttl-v": {"description": "in seconds, 14400 seconds by default", "format": "number", "default": 14400, "optional": true, "maximum": 864000, "minimum": 1, "type": "number"}, "dnssec-temp-name": {"description": "DNSSEC Template Name", "format": "string", "minLength": 1, "optional": false, "maxLength": 63, "type": "string"}, "signature-validity-period-v": {"description": "in days, 10 days by default", "format": "number", "default": 10, "optional": true, "maximum": 30, "minimum": 5, "type": "number"}, "dnssec-template-zsk": {"type": "object", "properties": {"zsk-keysize-v": {"description": "Default size is 2048 and must be an exact multiple of 64", "minimum": 1024, "type": "number", "maximum": 4096, "format": "number"}, "zsk-rollover-time-v": {"description": "7 days less than the lifetime by default", "format": "number", "default": 83, "maximum": 3650, "minimum": 1, "type": "number"}, "zsk-lifetime-v": {"description": "Default value is 90 days", "format": "number", "default": 90, "maximum": 3650, "minimum": 2, "type": "number"}, "zsk-lifetime-k": {"default": 0, "type": "number", "description": "Set the lifetime for DNSSEC ZSK keys in days", "format": "flag"}, "zsk-keysize-k": {"default": 0, "type": "number", "description": "Specify the number of bits in the DNSSEC ZSK keys", "format": "flag"}, "zsk-rollover-time-k": {"default": 0, "type": "number", "description": "Set the rollover time in days", "format": "flag"}}}}}], "type": "array", "$ref": "/axapi/v3/dnssec/template/{dnssec-temp-name}"}
    :param DeviceProxy: The device proxy for REST operations and session handling. Refer to `common/device_proxy.py`

    

    URL for this object::
    `https://<Hostname|Ip address>//axapi/v3/dnssec`.

    

    
    """
    def __init__(self, **kwargs):
        self.ERROR_MSG = ""
        self.required=[]
        self.b_key = "dnssec"
        self.a10_url="/axapi/v3/dnssec"
        self.DeviceProxy = ""
        self.key_rollover = {}
        self.standalone = ""
        self.sign_zone_now = {}
        self.dnskey = {}
        self.template_list = []
        self.ds = {}

        for keys, value in kwargs.items():
            setattr(self,keys, value)





from a10sdk.common.A10BaseClass import A10BaseClass


class Kerberos(A10BaseClass):
    
    """Class Description::
    Kerberos Authentication Relay.

    Class kerberos supports CRUD Operations and inherits from `common/A10BaseClass`.
    This class is the `"PARENT"` class for this module.`

    :param instance_list: {"minItems": 1, "items": {"type": "instance"}, "uniqueItems": true, "array": [{"required": ["name"], "properties": {"kerberos-account": {"description": "Specify the kerberos account name", "format": "string-rlx", "minLength": 1, "optional": true, "maxLength": 127, "type": "string"}, "name": {"description": "Specify Kerberos authentication relay name", "format": "string", "minLength": 1, "optional": false, "maxLength": 63, "type": "string"}, "encrypted": {"optional": true, "type": "encrypted", "description": "Do NOT use this option manually. (This is an A10 reserved keyword.) (The ENCRYPTED secret string)", "format": "encrypted"}, "kerberos-realm": {"description": "Specify the kerberos realm", "format": "string", "minLength": 1, "optional": true, "maxLength": 63, "type": "string"}, "kerberos-kdc-service-group": {"description": "Specify an authentication service group as multiple KDCs", "format": "string-rlx", "minLength": 1, "optional": true, "maxLength": 127, "not": "kerberos-kdc", "type": "string", "$ref": "/axapi/v3/aam/authentication/service-group"}, "timeout": {"description": "Specify timeout for kerberos transport, default is 10 seconds (The timeout, default is 10 seconds)", "format": "number", "default": 10, "optional": true, "maximum": 255, "minimum": 1, "type": "number"}, "password": {"default": 0, "optional": true, "type": "number", "description": "Specify password of Kerberos password", "format": "flag"}, "kerberos-kdc": {"description": "Specify the kerberos kdc ip or host name", "format": "string", "minLength": 1, "optional": true, "maxLength": 63, "not": "kerberos-kdc-service-group", "type": "string"}, "port": {"description": "Specify The KDC port, default is 88", "format": "number", "default": 88, "optional": true, "maximum": 65535, "minimum": 1, "type": "number"}, "secret-string": {"description": "The kerberos client password", "format": "password", "minLength": 1, "optional": true, "maxLength": 63, "type": "string"}}}], "type": "array", "$ref": "/axapi/v3/aam/authentication/relay/kerberos/instance/{name}"}
    :param DeviceProxy: The device proxy for REST operations and session handling. Refer to `common/device_proxy.py`

    

    URL for this object::
    `https://<Hostname|Ip address>//axapi/v3/aam/authentication/relay/kerberos`.

    

    
    """
    def __init__(self, **kwargs):
        self.ERROR_MSG = ""
        self.required=[]
        self.b_key = "kerberos"
        self.a10_url="/axapi/v3/aam/authentication/relay/kerberos"
        self.DeviceProxy = ""
        self.instance_list = []

        for keys, value in kwargs.items():
            setattr(self,keys, value)





from a10sdk.common.A10BaseClass import A10BaseClass


class Monitor(A10BaseClass):
    
    """Class Description::
    System monitor configuration.

    Class monitor supports CRUD Operations and inherits from `common/A10BaseClass`.
    This class is the `"PARENT"` class for this module.`

    :param data_cpu: {"description": "Monitor data CPU threshold (Threshold value in percentage, default 90)", "format": "number", "default": 90, "optional": true, "maximum": 100, "minimum": 1, "type": "number"}
    :param conn_type0: {"description": "Conn resource type 0 (Threshold value, default 32767)", "format": "number", "default": 32767, "optional": true, "maximum": 256000000, "minimum": 32767, "type": "number"}
    :param buffer_usage: {"description": "Monitor IO buffer usage threshold (Threshold value)", "format": "number", "type": "number", "maximum": 4000000, "minimum": 60000, "optional": true}
    :param smp_type1: {"description": "SMP resource type 1 (Threshold value, default 32767)", "format": "number", "default": 32767, "optional": true, "maximum": 256000000, "minimum": 32767, "type": "number"}
    :param conn_type4: {"description": "Conn resource type 4 (Threshold value, default 32767)", "format": "number", "default": 32767, "optional": true, "maximum": 256000000, "minimum": 32767, "type": "number"}
    :param smp_type3: {"description": "SMP resource type 3 (Threshold value, default 32767)", "format": "number", "default": 32767, "optional": true, "maximum": 256000000, "minimum": 32767, "type": "number"}
    :param ctrl_cpu: {"description": "Monitor control CPU threshold (Threshold value in percentage, default 90)", "format": "number", "default": 90, "optional": true, "maximum": 100, "minimum": 1, "type": "number"}
    :param warn_temp: {"description": "Monitor warning system temperature threshold (Threshold value in Celsius, default 68)", "format": "number", "default": 68, "optional": true, "maximum": 68, "minimum": 1, "type": "number"}
    :param smp_type2: {"description": "SMP resource type 2 (Threshold value, default 32767)", "format": "number", "default": 32767, "optional": true, "maximum": 256000000, "minimum": 32767, "type": "number"}
    :param memory: {"description": "Monitor memory usage threshold (Threshold value in percentage, default 95)", "format": "number", "default": 95, "optional": true, "maximum": 100, "minimum": 1, "type": "number"}
    :param conn_type3: {"description": "Conn resource type 3 (Threshold value, default 32767)", "format": "number", "default": 32767, "optional": true, "maximum": 256000000, "minimum": 32767, "type": "number"}
    :param conn_type2: {"description": "Conn resource type 2 (Threshold value, default 32767)", "format": "number", "default": 32767, "optional": true, "maximum": 256000000, "minimum": 32767, "type": "number"}
    :param conn_type1: {"description": "Conn resource type 1 (Threshold value, default 32767)", "format": "number", "default": 32767, "optional": true, "maximum": 256000000, "minimum": 32767, "type": "number"}
    :param disk: {"description": "Monitor hard disk usage threshold (Threshold value in percentage, default 85)", "format": "number", "default": 85, "optional": true, "maximum": 100, "minimum": 1, "type": "number"}
    :param smp_type0: {"description": "SMP resource type 0 (Threshold value, default 32767)", "format": "number", "default": 32767, "optional": true, "maximum": 256000000, "minimum": 32767, "type": "number"}
    :param smp_type4: {"description": "SMP resource type 4 (Threshold value, default 32767)", "format": "number", "default": 32767, "optional": true, "maximum": 256000000, "minimum": 32767, "type": "number"}
    :param buffer_drop: {"description": "Monitor buffer drop threshold (Threshold value)", "format": "number", "default": 4000, "optional": true, "maximum": 32767, "minimum": 1, "type": "number"}
    :param DeviceProxy: The device proxy for REST operations and session handling. Refer to `common/device_proxy.py`

    

    URL for this object::
    `https://<Hostname|Ip address>//axapi/v3/monitor`.

    

    
    """
    def __init__(self, **kwargs):
        self.ERROR_MSG = ""
        self.required=[]
        self.b_key = "monitor"
        self.a10_url="/axapi/v3/monitor"
        self.DeviceProxy = ""
        self.data_cpu = ""
        self.conn_type0 = ""
        self.buffer_usage = ""
        self.smp_type1 = ""
        self.conn_type4 = ""
        self.smp_type3 = ""
        self.ctrl_cpu = ""
        self.warn_temp = ""
        self.smp_type2 = ""
        self.memory = ""
        self.conn_type3 = ""
        self.conn_type2 = ""
        self.conn_type1 = ""
        self.disk = ""
        self.smp_type0 = ""
        self.smp_type4 = ""
        self.buffer_drop = ""

        for keys, value in kwargs.items():
            setattr(self,keys, value)





from a10sdk.common.A10BaseClass import A10BaseClass


class Ethernet(A10BaseClass):
    
    """Class Description::
    select ethernet interface to monitor.

    Class ethernet supports CRUD Operations and inherits from `common/A10BaseClass`.
    This class is the `"PARENT"` class for this module.`

    :param ifindex: {"optional": false, "$ref": "/axapi/v3/interface/ethernet", "type": "number", "description": "Ethernet interface number", "format": "interface"}
    :param DeviceProxy: The device proxy for REST operations and session handling. Refer to `common/device_proxy.py`

    

    URL for this object::
    `https://<Hostname|Ip address>//axapi/v3/netflow/monitor/{name}/sample/ethernet/{ifindex}`.

    

    
    """
    def __init__(self, **kwargs):
        self.ERROR_MSG = ""
        self.required = [ "ifindex"]

        self.b_key = "ethernet"
        self.a10_url="/axapi/v3/netflow/monitor/{name}/sample/ethernet/{ifindex}"
        self.DeviceProxy = ""
        self.ifindex = ""

        for keys, value in kwargs.items():
            setattr(self,keys, value)





from a10sdk.common.A10BaseClass import A10BaseClass


class Host(A10BaseClass):
    
    """Class Description::
    Set remote syslog host DNS name or ip address.

    Class host supports CRUD Operations and inherits from `common/A10BaseClass`.
    This class is the `"PARENT"` class for this module.`

    :param ipv6addr_list: {"minItems": 1, "items": {"type": "ipv6addr"}, "uniqueItems": true, "array": [{"required": ["host-ipv6"], "properties": {"host-ipv6": {"optional": false, "type": "string", "description": "Set syslog host ipv6 address", "format": "ipv6-address"}, "tcp": {"description": "Use TCP as transport protocol", "partition-visibility": "shared", "default": 0, "type": "number", "format": "flag", "optional": true}, "port": {"description": "Set remote syslog port number", "format": "number", "default": 514, "optional": true, "maximum": 32767, "minimum": 1, "type": "number"}, "use-mgmt-port": {"description": "Use management port for connections", "partition-visibility": "shared", "default": 0, "type": "number", "format": "flag", "optional": true}}}], "type": "array", "$ref": "/axapi/v3/logging/host/ipv6addr/{host-ipv6}"}
    :param ipv4addr_list: {"minItems": 1, "items": {"type": "ipv4addr"}, "uniqueItems": true, "array": [{"required": ["host-ipv4"], "properties": {"tcp": {"description": "Use TCP as transport protocol", "partition-visibility": "shared", "default": 0, "type": "number", "format": "flag", "optional": true}, "host-ipv4": {"optional": false, "type": "string", "description": "Set syslog host ip address", "format": "host"}, "port": {"description": "Set remote syslog port number", "format": "number", "default": 514, "optional": true, "maximum": 32767, "minimum": 1, "type": "number"}, "use-mgmt-port": {"description": "Use management port for connections", "partition-visibility": "shared", "default": 0, "type": "number", "format": "flag", "optional": true}}}], "type": "array", "$ref": "/axapi/v3/logging/host/ipv4addr/{host-ipv4}"}
    :param DeviceProxy: The device proxy for REST operations and session handling. Refer to `common/device_proxy.py`

    

    URL for this object::
    `https://<Hostname|Ip address>//axapi/v3/logging/host`.

    

    
    """
    def __init__(self, **kwargs):
        self.ERROR_MSG = ""
        self.required=[]
        self.b_key = "host"
        self.a10_url="/axapi/v3/logging/host"
        self.DeviceProxy = ""
        self.ipv6addr_list = []
        self.partition = {}
        self.ipv4addr_list = []

        for keys, value in kwargs.items():
            setattr(self,keys, value)





from a10sdk.common.A10BaseClass import A10BaseClass


class Logging(A10BaseClass):
    
    """Class Description::
    Logging template.

    Class logging supports CRUD Operations and inherits from `common/A10BaseClass`.
    This class is the `"PARENT"` class for this module.`

    :param name: {"description": "Logging Template Name", "format": "string", "minLength": 1, "optional": false, "maxLength": 63, "type": "string"}
    :param format: {"description": "Specfiy a format string for web logging (format string(less than 250 characters) for web logging)", "format": "string-rlx", "minLength": 1, "optional": true, "maxLength": 250, "type": "string"}
    :param local_logging: {"description": "1 to enable local logging", "format": "number", "type": "number", "maximum": 1, "minimum": 0, "optional": true}
    :param keep_end: {"description": "Number of unmasked characters at the end (default: 0)", "format": "number", "type": "number", "maximum": 65535, "minimum": 0, "optional": true}
    :param mask: {"description": "Character to mask the matched pattern (default: X)", "format": "string", "minLength": 1, "optional": true, "maxLength": 1, "type": "string"}
    :param keep_start: {"description": "Number of unmasked characters at the beginning (default: 0)", "format": "number", "type": "number", "maximum": 65535, "minimum": 0, "optional": true}
    :param service_group: {"description": "Bind a Service Group to the logging template (Service Group Name)", "format": "string-rlx", "minLength": 1, "optional": true, "maxLength": 127, "type": "string", "$ref": "/axapi/v3/slb/service-group"}
    :param pcre_mask: {"description": "Mask matched PCRE pattern in the log", "format": "string-rlx", "minLength": 1, "optional": true, "maxLength": 63, "type": "string"}
    :param tcp_proxy: {"description": "TCP proxy template (TCP Proxy Config name)", "format": "string", "default": "default", "minLength": 1, "optional": true, "maxLength": 63, "type": "string"}
    :param DeviceProxy: The device proxy for REST operations and session handling. Refer to `common/device_proxy.py`

    

    URL for this object::
    `https://<Hostname|Ip address>//axapi/v3/slb/template/logging/{name}`.

    

    
    """
    def __init__(self, **kwargs):
        self.ERROR_MSG = ""
        self.required = [ "name"]

        self.b_key = "logging"
        self.a10_url="/axapi/v3/slb/template/logging/{name}"
        self.DeviceProxy = ""
        self.name = ""
        self.A10WW_format = ""
        self.local_logging = ""
        self.keep_end = ""
        self.mask = ""
        self.keep_start = ""
        self.service_group = ""
        self.pcre_mask = ""
        self.tcp_proxy = ""

        for keys, value in kwargs.items():
            setattr(self,keys, value)





from a10sdk.common.A10BaseClass import A10BaseClass


class Radius(A10BaseClass):
    
    """This class does not support CRUD Operations please use parent.

    :param exact_value_lsn_lid: {"description": "LSN Limit ID (LID index)", "minimum": 1, "type": "number", "maximum": 1023, "format": "number"}
    :param attribute: {"enum": ["custom1", "custom2", "custom3", "imei", "imsi", "msisdn", "default"], "type": "string", "description": "'custom1': Configure RADIUS Attribute Custom 1; 'custom2': Configure RADIUS Attribute Custom 2; 'custom3': Configure RADIUS Attribute Custom 3; 'imei': Configure RADIUS Attribute IMEI; 'imsi': Configure RADIUS Attribute IMSI; 'msisdn': Configure RADIUS Attribute MSISDN; 'default': Configure default; ", "format": "enum"}
    :param starts_with_lsn_lid: {"description": "LSN Limit ID (LID index)", "minimum": 1, "type": "number", "maximum": 1023, "format": "number"}
    :param exact_value: {"minLength": 1, "maxLength": 31, "type": "string", "description": "Value of the attribute", "format": "string-rlx"}
    :param starts_with: {"minLength": 1, "maxLength": 31, "type": "string", "description": "Value of the attribute", "format": "string-rlx"}
    :param default_lsn_lid: {"description": "LSN Limit ID (LID index)", "minimum": 1, "type": "number", "maximum": 1023, "format": "number"}
    :param DeviceProxy: The device proxy for REST operations and session handling. Refer to `common/device_proxy.py`

    

    
    """
    def __init__(self, **kwargs):
        self.ERROR_MSG = ""
        
        self.b_key = "radius"
        self.DeviceProxy = ""
        self.exact_value_lsn_lid = ""
        self.attribute = ""
        self.starts_with_lsn_lid = ""
        self.exact_value = ""
        self.starts_with = ""
        self.default_lsn_lid = ""

        for keys, value in kwargs.items():
            setattr(self,keys, value)


class LsnRadiusProfile(A10BaseClass):
    
    """Class Description::
    Configure LSN RADIUS Profile.

    Class lsn-radius-profile supports CRUD Operations and inherits from `common/A10BaseClass`.
    This class is the `"PARENT"` class for this module.`

    :param lid_profile_index: {"description": "LSN RADIUS Profile Index", "format": "number", "type": "number", "maximum": 16, "minimum": 1, "optional": false}
    :param radius: {"minItems": 1, "items": {"type": "object"}, "uniqueItems": true, "type": "array", "array": [{"properties": {"exact-value-lsn-lid": {"description": "LSN Limit ID (LID index)", "minimum": 1, "type": "number", "maximum": 1023, "format": "number"}, "attribute": {"enum": ["custom1", "custom2", "custom3", "imei", "imsi", "msisdn", "default"], "type": "string", "description": "'custom1': Configure RADIUS Attribute Custom 1; 'custom2': Configure RADIUS Attribute Custom 2; 'custom3': Configure RADIUS Attribute Custom 3; 'imei': Configure RADIUS Attribute IMEI; 'imsi': Configure RADIUS Attribute IMSI; 'msisdn': Configure RADIUS Attribute MSISDN; 'default': Configure default; ", "format": "enum"}, "starts-with-lsn-lid": {"description": "LSN Limit ID (LID index)", "minimum": 1, "type": "number", "maximum": 1023, "format": "number"}, "exact-value": {"minLength": 1, "maxLength": 31, "type": "string", "description": "Value of the attribute", "format": "string-rlx"}, "starts-with": {"minLength": 1, "maxLength": 31, "type": "string", "description": "Value of the attribute", "format": "string-rlx"}, "default-lsn-lid": {"description": "LSN Limit ID (LID index)", "minimum": 1, "type": "number", "maximum": 1023, "format": "number"}, "optional": true}}]}
    :param DeviceProxy: The device proxy for REST operations and session handling. Refer to `common/device_proxy.py`

    

    URL for this object::
    `https://<Hostname|Ip address>//axapi/v3/cgnv6/lsn-radius-profile/{lid_profile_index}`.

    

    
    """
    def __init__(self, **kwargs):
        self.ERROR_MSG = ""
        self.required = [ "lid_profile_index"]

        self.b_key = "lsn-radius-profile"
        self.a10_url="/axapi/v3/cgnv6/lsn-radius-profile/{lid_profile_index}"
        self.DeviceProxy = ""
        self.lid_profile_index = ""
        self.radius = []

        for keys, value in kwargs.items():
            setattr(self,keys, value)





from a10sdk.common.A10BaseClass import A10BaseClass


class Inside(A10BaseClass):
    
    """Class Description::
    Fixed NAT Inside Users.

    Class inside supports CRUD Operations and inherits from `common/A10BaseClass`.
    This class is the `"PARENT"` class for this module.`

    :param iplist_list: {"minItems": 1, "items": {"type": "iplist"}, "uniqueItems": true, "array": [{"required": ["inside-ip-list", "partition"], "properties": {"ports-per-user": {"description": "Configure Ports per Inside User (ports-per-user)", "format": "number", "type": "number", "maximum": 64512, "minimum": 1, "optional": true}, "vrid": {"description": "VRRP-A vrid (Specify ha VRRP-A vrid)", "format": "number", "type": "number", "maximum": 31, "minimum": 1, "optional": true}, "nat-end-address": {"optional": true, "type": "string", "description": "IPv4 End NAT Address", "format": "ipv4-address"}, "partition": {"description": "Inside User Partition (Partition Name)", "partition-visibility": "shared", "minLength": 1, "format": "string", "optional": false, "maxLength": 63, "type": "string"}, "nat-netmask": {"optional": true, "type": "string", "description": "NAT Addresses IP Netmask", "format": "ipv4-netmask"}, "inside-ip-list": {"description": "Name of IP List used to specify Inside Users", "format": "string-rlx", "minLength": 1, "optional": false, "maxLength": 63, "type": "string"}, "session-quota": {"description": "Configure per user quota on sessions", "format": "number", "type": "number", "maximum": 2147483647, "minimum": 1, "optional": true}, "usable-nat-ports": {"type": "object", "properties": {"usable-start-port": {"description": "Start Port of Usable NAT Ports", "minimum": 1024, "type": "number", "maximum": 65535, "format": "number"}, "usable-end-port": {"description": "End Port of Usable NAT Ports", "minimum": 1024, "type": "number", "maximum": 65535, "format": "number"}}}, "nat-start-address": {"optional": true, "type": "string", "description": "Start NAT Address", "format": "ipv4-address"}, "nat-ip-list": {"description": "Name of IP List used to specify NAT addresses", "format": "string-rlx", "minLength": 1, "optional": true, "maxLength": 63, "type": "string"}, "offset": {"type": "object", "properties": {"numeric-offset": {"description": "Configure a numeric offset to the first NAT IP address", "format": "number", "default": 0, "maximum": 1024000, "minimum": 0, "not": "random", "type": "number"}, "random": {"default": 0, "not": "numeric-offset", "type": "number", "description": "Randomly choose the first NAT IP address", "format": "flag"}}}, "respond-to-user-mac": {"default": 0, "optional": true, "type": "number", "description": "Use the user's source MAC for the next hop rather than the routing table (Default: off)", "format": "flag"}, "method": {"description": "'use-all-nat-ips': Use all the NAT IP addresses configured; 'use-least-nat-ips': Use the least number of NAT IP addresses required (default); ", "format": "enum", "default": "use-least-nat-ips", "type": "string", "enum": ["use-all-nat-ips", "use-least-nat-ips"], "optional": true}, "dest-rule-list": {"description": "Bind destination based Rule-List (Fixed NAT Rule-List Name)", "format": "string", "minLength": 1, "optional": true, "maxLength": 63, "type": "string"}, "dynamic-pool-size": {"description": "Configure size of Dynamic pool (Default: 0)", "format": "number", "default": 0, "optional": true, "maximum": 64511, "minimum": 0, "type": "number"}}}], "type": "array", "$ref": "/axapi/v3/cgnv6/fixed-nat/inside/iplist/{inside-ip-list}+{partition}"}
    :param ipv4address_list: {"minItems": 1, "items": {"type": "ipv4address"}, "uniqueItems": true, "array": [{"required": ["inside-start-address", "inside-end-address", "inside-netmask", "partition"], "properties": {"ports-per-user": {"description": "Configure Ports per Inside User (ports-per-user)", "format": "number", "type": "number", "maximum": 64512, "minimum": 1, "optional": true}, "vrid": {"description": "VRRP-A vrid (Specify ha VRRP-A vrid)", "format": "number", "type": "number", "maximum": 31, "minimum": 1, "optional": true}, "inside-netmask": {"optional": false, "type": "string", "description": "IPv4 Netmask", "format": "ipv4-netmask-brief"}, "nat-end-address": {"optional": true, "type": "string", "description": "IPv4 End NAT Address", "format": "ipv4-address"}, "usable-nat-ports": {"type": "object", "properties": {"usable-start-port": {"description": "Start Port of Usable NAT Ports", "minimum": 1024, "type": "number", "maximum": 65535, "format": "number"}, "usable-end-port": {"description": "End Port of Usable NAT Ports", "minimum": 1024, "type": "number", "maximum": 65535, "format": "number"}}}, "partition": {"description": "Inside User Partition (Partition Name)", "partition-visibility": "shared", "minLength": 1, "format": "string", "optional": false, "maxLength": 63, "type": "string"}, "nat-netmask": {"optional": true, "type": "string", "description": "NAT Addresses IP Netmask", "format": "ipv4-netmask-brief"}, "session-quota": {"description": "Configure per user quota on sessions", "format": "number", "type": "number", "maximum": 2147483647, "minimum": 1, "optional": true}, "method": {"description": "'use-all-nat-ips': Use all the NAT IP addresses configured; 'use-least-nat-ips': Use the least number of NAT IP addresses required (default); ", "format": "enum", "default": "use-least-nat-ips", "type": "string", "enum": ["use-all-nat-ips", "use-least-nat-ips"], "optional": true}, "inside-start-address": {"optional": false, "type": "string", "description": "IPv4 Inside User Start Address", "format": "ipv4-address"}, "nat-start-address": {"optional": true, "type": "string", "description": "Start NAT Address", "format": "ipv4-address"}, "nat-ip-list": {"description": "Name of IP List used to specify NAT addresses", "format": "string-rlx", "minLength": 1, "optional": true, "maxLength": 63, "type": "string"}, "offset": {"type": "object", "properties": {"numeric-offset": {"description": "Configure a numeric offset to the first NAT IP address", "format": "number", "default": 0, "maximum": 1024000, "minimum": 0, "not": "random", "type": "number"}, "random": {"default": 0, "not": "numeric-offset", "type": "number", "description": "Randomly choose the first NAT IP address", "format": "flag"}}}, "respond-to-user-mac": {"default": 0, "optional": true, "type": "number", "description": "Use the user's source MAC for the next hop rather than the routing table (Default: off)", "format": "flag"}, "inside-end-address": {"optional": false, "type": "string", "description": "IPv4 Inside User End Address", "format": "ipv4-address"}, "dest-rule-list": {"description": "Bind destination based Rule-List (Fixed NAT Rule-List Name)", "format": "string", "minLength": 1, "optional": true, "maxLength": 63, "type": "string"}, "dynamic-pool-size": {"description": "Configure size of Dynamic pool (Default: 0)", "format": "number", "default": 0, "optional": true, "maximum": 64511, "minimum": 0, "type": "number"}}}], "type": "array", "$ref": "/axapi/v3/cgnv6/fixed-nat/inside/ipv4address/{inside-start-address}+{inside-end-address}+{inside-netmask}+{partition}"}
    :param ipv6address_list: {"minItems": 1, "items": {"type": "ipv6address"}, "uniqueItems": true, "array": [{"required": ["inside-start-address", "inside-end-address", "inside-netmask", "partition"], "properties": {"ports-per-user": {"description": "Configure Ports per Inside User (ports-per-user)", "format": "number", "type": "number", "maximum": 64512, "minimum": 1, "optional": true}, "vrid": {"description": "VRRP-A vrid (Specify ha VRRP-A vrid)", "format": "number", "type": "number", "maximum": 31, "minimum": 1, "optional": true}, "inside-netmask": {"description": "Inside User IPv6 Netmask", "format": "number", "type": "number", "maximum": 128, "minimum": 64, "optional": false}, "nat-end-address": {"optional": true, "type": "string", "description": "IPv6 End NAT Address", "format": "ipv4-address"}, "usable-nat-ports": {"type": "object", "properties": {"usable-start-port": {"description": "Start Port of Usable NAT Ports", "minimum": 1024, "type": "number", "maximum": 65535, "format": "number"}, "usable-end-port": {"description": "End Port of Usable NAT Ports", "minimum": 1024, "type": "number", "maximum": 65535, "format": "number"}}}, "partition": {"description": "Inside User Partition (Partition Name)", "partition-visibility": "shared", "minLength": 1, "format": "string", "optional": false, "maxLength": 63, "type": "string"}, "nat-netmask": {"optional": true, "type": "string", "description": "NAT Addresses IP Netmask", "format": "ipv4-netmask-brief"}, "session-quota": {"description": "Configure per user quota on sessions", "format": "number", "type": "number", "maximum": 2147483647, "minimum": 1, "optional": true}, "method": {"description": "'use-all-nat-ips': Use all the NAT IP addresses configured; 'use-least-nat-ips': Use the least number of NAT IP addresses required (default); ", "format": "enum", "default": "use-least-nat-ips", "type": "string", "enum": ["use-all-nat-ips", "use-least-nat-ips"], "optional": true}, "inside-start-address": {"optional": false, "type": "string", "description": "IPv6 Inside User Start Address", "format": "ipv6-address"}, "nat-start-address": {"optional": true, "type": "string", "description": "Start NAT Address", "format": "ipv4-address"}, "nat-ip-list": {"description": "Name of IP List used to specify NAT addresses", "format": "string-rlx", "minLength": 1, "optional": true, "maxLength": 63, "type": "string"}, "offset": {"type": "object", "properties": {"numeric-offset": {"description": "Configure a numeric offset to the first NAT IP address", "format": "number", "default": 0, "maximum": 1024000, "minimum": 0, "not": "random", "type": "number"}, "random": {"default": 0, "not": "numeric-offset", "type": "number", "description": "Randomly choose the first NAT IP address", "format": "flag"}}}, "respond-to-user-mac": {"default": 0, "optional": true, "type": "number", "description": "Use the user's source MAC for the next hop rather than the routing table (Default: off)", "format": "flag"}, "inside-end-address": {"optional": false, "type": "string", "description": "IPv6 Inside User End Address", "format": "ipv6-address"}, "dest-rule-list": {"description": "Bind destination based Rule-List (Fixed NAT Rule-List Name)", "format": "string", "minLength": 1, "optional": true, "maxLength": 63, "type": "string"}, "dynamic-pool-size": {"description": "Configure size of Dynamic pool (Default: 0)", "format": "number", "default": 0, "optional": true, "maximum": 64511, "minimum": 0, "type": "number"}}}], "type": "array", "$ref": "/axapi/v3/cgnv6/fixed-nat/inside/ipv6address/{inside-start-address}+{inside-end-address}+{inside-netmask}+{partition}"}
    :param DeviceProxy: The device proxy for REST operations and session handling. Refer to `common/device_proxy.py`

    

    URL for this object::
    `https://<Hostname|Ip address>//axapi/v3/cgnv6/fixed-nat/inside`.

    

    
    """
    def __init__(self, **kwargs):
        self.ERROR_MSG = ""
        self.required=[]
        self.b_key = "inside"
        self.a10_url="/axapi/v3/cgnv6/fixed-nat/inside"
        self.DeviceProxy = ""
        self.iplist_list = []
        self.ipv4address_list = []
        self.ipv6address_list = []

        for keys, value in kwargs.items():
            setattr(self,keys, value)





from a10sdk.common.A10BaseClass import A10BaseClass


class Oper(A10BaseClass):
    
    """This class does not support CRUD Operations please use parent.

    :param alloc_failed: {"type": "number", "format": "number"}
    :param vrid: {"enum": ["default"], "type": "string", "format": "enum"}
    :param ha_group_id: {"enum": ["default"], "type": "string", "format": "enum"}
    :param ip: {"type": "string", "format": "ipv4-address"}
    :param ports_consumed: {"type": "number", "format": "number"}
    :param state: {"enum": ["UP", "DOWN", "DELETE", "DISABLED", "MAINTENANCE"], "type": "string", "format": "enum"}
    :param ipv6: {"type": "string", "format": "ipv6-address"}
    :param ports_freed_total: {"type": "number", "format": "number"}
    :param ports_consumed_total: {"type": "number", "format": "number"}
    :param DeviceProxy: The device proxy for REST operations and session handling. Refer to `common/device_proxy.py`

    

    
    """
    def __init__(self, **kwargs):
        self.ERROR_MSG = ""
        
        self.b_key = "oper"
        self.DeviceProxy = ""
        self.alloc_failed = ""
        self.vrid = ""
        self.ha_group_id = ""
        self.ip = ""
        self.ports_consumed = ""
        self.state = ""
        self.ipv6 = ""
        self.ports_freed_total = ""
        self.ports_consumed_total = ""

        for keys, value in kwargs.items():
            setattr(self,keys, value)


class Port(A10BaseClass):
    
    """Class Description::
    Operational Status for the object port.

    Class port supports CRUD Operations and inherits from `common/A10BaseClass`.
    This class is the `"PARENT"` class for this module.`

    :param protocol: {"enum": ["tcp", "udp"], "description": "'tcp': TCP Port; 'udp': UDP Port; ", "format": "enum", "type": "string", "oid": "1002", "optional": false}
    :param port_number: {"description": "Port Number", "format": "number", "optional": false, "oid": "1001", "maximum": 65534, "minimum": 0, "type": "number"}
    :param DeviceProxy: The device proxy for REST operations and session handling. Refer to `common/device_proxy.py`

    

    URL for this object::
    `https://<Hostname|Ip address>//axapi/v3/cgnv6/server/{name}/port/{port_number}+{protocol}/oper`.

    

    
    """
    def __init__(self, **kwargs):
        self.ERROR_MSG = ""
        self.required=[]
        self.b_key = "port"
        self.a10_url="/axapi/v3/cgnv6/server/{name}/port/{port_number}+{protocol}/oper"
        self.DeviceProxy = ""
        self.oper = {}
        self.protocol = ""
        self.port_number = ""

        for keys, value in kwargs.items():
            setattr(self,keys, value)





from a10sdk.common.A10BaseClass import A10BaseClass


class ClassListList(A10BaseClass):
    
    """This class does not support CRUD Operations please use parent.

    :param period: {"description": "Specify the period in second", "format": "number", "type": "number", "maximum": 31536000, "minimum": 60, "optional": true}
    :param remote_file: {"optional": true, "type": "string", "description": "profile name for remote url", "format": "url"}
    :param use_mgmt_port: {"default": 0, "optional": true, "type": "number", "description": "Use management port as source port", "format": "flag"}
    :param class_list: {"description": "Class List File", "format": "string", "minLength": 1, "optional": false, "maxLength": 63, "type": "string"}
    :param DeviceProxy: The device proxy for REST operations and session handling. Refer to `common/device_proxy.py`

    

    
    """
    def __init__(self, **kwargs):
        self.ERROR_MSG = ""
        
        self.b_key = "class-list-list"
        self.DeviceProxy = ""
        self.period = ""
        self.remote_file = ""
        self.use_mgmt_port = ""
        self.class_list = ""

        for keys, value in kwargs.items():
            setattr(self,keys, value)


class BwListList(A10BaseClass):
    
    """This class does not support CRUD Operations please use parent.

    :param remote_file: {"optional": true, "type": "string", "description": "profile name for remote url", "format": "url"}
    :param bw_list: {"description": "Black white List File", "format": "string", "minLength": 1, "optional": false, "maxLength": 63, "type": "string"}
    :param use_mgmt_port: {"default": 0, "optional": true, "type": "number", "description": "Use management port as source port", "format": "flag"}
    :param period: {"description": "Specify the period in second", "format": "number", "type": "number", "maximum": 31536000, "minimum": 60, "optional": true}
    :param DeviceProxy: The device proxy for REST operations and session handling. Refer to `common/device_proxy.py`

    

    
    """
    def __init__(self, **kwargs):
        self.ERROR_MSG = ""
        
        self.b_key = "bw-list-list"
        self.DeviceProxy = ""
        self.remote_file = ""
        self.bw_list = ""
        self.use_mgmt_port = ""
        self.period = ""

        for keys, value in kwargs.items():
            setattr(self,keys, value)


class IpMapListList(A10BaseClass):
    
    """This class does not support CRUD Operations please use parent.

    :param ip_map_list: {"description": "IP Map List File", "format": "string", "minLength": 1, "optional": false, "maxLength": 63, "type": "string"}
    :param remote_file: {"optional": true, "type": "string", "description": "profile name for remote url", "format": "url"}
    :param use_mgmt_port: {"default": 0, "optional": true, "type": "number", "description": "Use management port as source port", "format": "flag"}
    :param period: {"description": "Specify the period in second", "format": "number", "type": "number", "maximum": 31536000, "minimum": 60, "optional": true}
    :param DeviceProxy: The device proxy for REST operations and session handling. Refer to `common/device_proxy.py`

    

    
    """
    def __init__(self, **kwargs):
        self.ERROR_MSG = ""
        
        self.b_key = "ip-map-list-list"
        self.DeviceProxy = ""
        self.ip_map_list = ""
        self.remote_file = ""
        self.use_mgmt_port = ""
        self.period = ""

        for keys, value in kwargs.items():
            setattr(self,keys, value)


class ExportPeriodic(A10BaseClass):
    
    """Class Description::
    Put files to remote site periodically.

    Class export-periodic supports CRUD Operations and inherits from `common/A10BaseClass`.
    This class is the `"PARENT"` class for this module.`

    :param ssl_key_list: {"minItems": 1, "items": {"type": "ssl-key"}, "uniqueItems": true, "array": [{"required": ["ssl-key"], "properties": {"period": {"description": "Specify the period in second", "format": "number", "type": "number", "maximum": 31536000, "minimum": 60, "optional": true}, "remote-file": {"optional": true, "type": "string", "description": "profile name for remote url", "format": "url"}, "use-mgmt-port": {"default": 0, "optional": true, "type": "number", "description": "Use management port as source port", "format": "flag"}, "ssl-key": {"description": "SSL Key File", "format": "string", "minLength": 1, "optional": false, "maxLength": 255, "type": "string"}}}], "type": "array", "$ref": "/axapi/v3/export-periodic/ssl-key/{ssl-key}"}
    :param local_uri_file_list: {"minItems": 1, "items": {"type": "local-uri-file"}, "uniqueItems": true, "array": [{"required": ["local-uri-file"], "properties": {"local-uri-file": {"description": "Local URI files for http response", "format": "string", "minLength": 1, "optional": false, "maxLength": 63, "type": "string"}, "remote-file": {"optional": true, "type": "string", "description": "profile name for remote url", "format": "url"}, "use-mgmt-port": {"default": 0, "optional": true, "type": "number", "description": "Use management port as source port", "format": "flag"}, "period": {"description": "Specify the period in second", "format": "number", "type": "number", "maximum": 31536000, "minimum": 60, "optional": true}}}], "type": "array", "$ref": "/axapi/v3/export-periodic/local-uri-file/{local-uri-file}"}
    :param ssl_cert_list: {"minItems": 1, "items": {"type": "ssl-cert"}, "uniqueItems": true, "array": [{"required": ["ssl-cert"], "properties": {"remote-file": {"optional": true, "type": "string", "description": "profile name for remote url", "format": "url"}, "ssl-cert": {"description": "SSL Cert File", "format": "string", "minLength": 1, "optional": false, "maxLength": 255, "type": "string"}, "use-mgmt-port": {"default": 0, "optional": true, "type": "number", "description": "Use management port as source port", "format": "flag"}, "period": {"description": "Specify the period in second", "format": "number", "type": "number", "maximum": 31536000, "minimum": 60, "optional": true}}}], "type": "array", "$ref": "/axapi/v3/export-periodic/ssl-cert/{ssl-cert}"}
    :param dnssec_ds_list: {"minItems": 1, "items": {"type": "dnssec-ds"}, "uniqueItems": true, "array": [{"required": ["dnssec-ds"], "properties": {"dnssec-ds": {"description": "DNSSEC DS file for child zone", "format": "string", "minLength": 1, "optional": false, "maxLength": 127, "type": "string"}, "remote-file": {"optional": true, "type": "string", "description": "profile name for remote url", "format": "url"}, "use-mgmt-port": {"default": 0, "optional": true, "type": "number", "description": "Use management port as source port", "format": "flag"}, "period": {"description": "Specify the period in second", "format": "number", "type": "number", "maximum": 31536000, "minimum": 60, "optional": true}}}], "type": "array", "$ref": "/axapi/v3/export-periodic/dnssec-ds/{dnssec-ds}"}
    :param xml_schema_list: {"minItems": 1, "items": {"type": "xml-schema"}, "uniqueItems": true, "array": [{"required": ["xml-schema"], "properties": {"period": {"description": "Specify the period in second", "format": "number", "type": "number", "maximum": 31536000, "minimum": 60, "optional": true}, "remote-file": {"optional": true, "type": "string", "description": "profile name for remote url", "format": "url"}, "use-mgmt-port": {"default": 0, "optional": true, "type": "number", "description": "Use management port as source port", "format": "flag"}, "xml-schema": {"description": "XML-Schema File", "format": "string", "minLength": 1, "optional": false, "maxLength": 63, "type": "string"}}}], "type": "array", "$ref": "/axapi/v3/export-periodic/xml-schema/{xml-schema}"}
    :param aflex_list: {"minItems": 1, "items": {"type": "aflex"}, "uniqueItems": true, "array": [{"required": ["aflex"], "properties": {"aflex": {"description": "aFleX Script Source File", "format": "string", "minLength": 1, "optional": false, "maxLength": 63, "type": "string"}, "remote-file": {"optional": true, "type": "string", "description": "profile name for remote url", "format": "url"}, "use-mgmt-port": {"default": 0, "optional": true, "type": "number", "description": "Use management port as source port", "format": "flag"}, "period": {"description": "Specify the period in second", "format": "number", "type": "number", "maximum": 31536000, "minimum": 60, "optional": true}}}], "type": "array", "$ref": "/axapi/v3/export-periodic/aflex/{aflex}"}
    :param dnssec_dnskey_list: {"minItems": 1, "items": {"type": "dnssec-dnskey"}, "uniqueItems": true, "array": [{"required": ["dnssec-dnskey"], "properties": {"remote-file": {"optional": true, "type": "string", "description": "profile name for remote url", "format": "url"}, "use-mgmt-port": {"default": 0, "optional": true, "type": "number", "description": "Use management port as source port", "format": "flag"}, "dnssec-dnskey": {"description": "DNSSEC DNSKEY(KSK) file for child zone", "format": "string", "minLength": 1, "optional": false, "maxLength": 127, "type": "string"}, "period": {"description": "Specify the period in second", "format": "number", "type": "number", "maximum": 31536000, "minimum": 60, "optional": true}}}], "type": "array", "$ref": "/axapi/v3/export-periodic/dnssec-dnskey/{dnssec-dnskey}"}
    :param geo_location_list: {"minItems": 1, "items": {"type": "geo-location"}, "uniqueItems": true, "array": [{"required": ["geo-location"], "properties": {"geo-location": {"description": "Geo-location CSV File", "partition-visibility": "shared", "minLength": 1, "format": "string", "optional": false, "maxLength": 63, "type": "string"}, "remote-file": {"optional": true, "type": "string", "description": "profile name for remote url", "format": "url"}, "use-mgmt-port": {"default": 0, "optional": true, "type": "number", "description": "Use management port as source port", "format": "flag"}, "period": {"description": "Specify the period in second", "format": "number", "type": "number", "maximum": 31536000, "minimum": 60, "optional": true}}}], "type": "array", "$ref": "/axapi/v3/export-periodic/geo-location/{geo-location}"}
    :param policy_list: {"minItems": 1, "items": {"type": "policy"}, "uniqueItems": true, "array": [{"required": ["policy"], "properties": {"policy": {"description": "WAF Policy File", "format": "string", "minLength": 1, "optional": false, "maxLength": 63, "type": "string"}, "remote-file": {"optional": true, "type": "string", "description": "profile name for remote url", "format": "url"}, "use-mgmt-port": {"default": 0, "optional": true, "type": "number", "description": "Use management port as source port", "format": "flag"}, "period": {"description": "Specify the period in second", "format": "number", "type": "number", "maximum": 31536000, "minimum": 60, "optional": true}}}], "type": "array", "$ref": "/axapi/v3/export-periodic/policy/{policy}"}
    :param class_list_list: {"minItems": 1, "items": {"type": "class-list"}, "uniqueItems": true, "array": [{"required": ["class-list"], "properties": {"period": {"description": "Specify the period in second", "format": "number", "type": "number", "maximum": 31536000, "minimum": 60, "optional": true}, "remote-file": {"optional": true, "type": "string", "description": "profile name for remote url", "format": "url"}, "use-mgmt-port": {"default": 0, "optional": true, "type": "number", "description": "Use management port as source port", "format": "flag"}, "class-list": {"description": "Class List File", "format": "string", "minLength": 1, "optional": false, "maxLength": 63, "type": "string"}}}], "type": "array", "$ref": "/axapi/v3/export-periodic/class-list/{class-list}"}
    :param wsdl_list: {"minItems": 1, "items": {"type": "wsdl"}, "uniqueItems": true, "array": [{"required": ["wsdl"], "properties": {"wsdl": {"description": "Web Services Definition Language File", "format": "string", "minLength": 1, "optional": false, "maxLength": 63, "type": "string"}, "remote-file": {"optional": true, "type": "string", "description": "profile name for remote url", "format": "url"}, "use-mgmt-port": {"default": 0, "optional": true, "type": "number", "description": "Use management port as source port", "format": "flag"}, "period": {"description": "Specify the period in second", "format": "number", "type": "number", "maximum": 31536000, "minimum": 60, "optional": true}}}], "type": "array", "$ref": "/axapi/v3/export-periodic/wsdl/{wsdl}"}
    :param bw_list_list: {"minItems": 1, "items": {"type": "bw-list"}, "uniqueItems": true, "array": [{"required": ["bw-list"], "properties": {"remote-file": {"optional": true, "type": "string", "description": "profile name for remote url", "format": "url"}, "bw-list": {"description": "Black white List File", "format": "string", "minLength": 1, "optional": false, "maxLength": 63, "type": "string"}, "use-mgmt-port": {"default": 0, "optional": true, "type": "number", "description": "Use management port as source port", "format": "flag"}, "period": {"description": "Specify the period in second", "format": "number", "type": "number", "maximum": 31536000, "minimum": 60, "optional": true}}}], "type": "array", "$ref": "/axapi/v3/export-periodic/bw-list/{bw-list}"}
    :param ip_map_list_list: {"minItems": 1, "items": {"type": "ip-map-list"}, "uniqueItems": true, "array": [{"required": ["ip-map-list"], "properties": {"ip-map-list": {"description": "IP Map List File", "format": "string", "minLength": 1, "optional": false, "maxLength": 63, "type": "string"}, "remote-file": {"optional": true, "type": "string", "description": "profile name for remote url", "format": "url"}, "use-mgmt-port": {"default": 0, "optional": true, "type": "number", "description": "Use management port as source port", "format": "flag"}, "period": {"description": "Specify the period in second", "format": "number", "type": "number", "maximum": 31536000, "minimum": 60, "optional": true}}}], "type": "array", "$ref": "/axapi/v3/export-periodic/ip-map-list/{ip-map-list}"}
    :param axdebug_list: {"minItems": 1, "items": {"type": "axdebug"}, "uniqueItems": true, "array": [{"required": ["axdebug"], "properties": {"merged-pcap": {"default": 0, "optional": true, "type": "number", "description": "Export the merged pcap file when there are multiple Export sessions", "format": "flag"}, "axdebug": {"description": "AX Debug Packet File", "format": "string", "minLength": 1, "optional": false, "maxLength": 63, "type": "string"}, "remote-file": {"optional": true, "type": "string", "description": "profile name for remote url", "format": "url"}, "use-mgmt-port": {"default": 0, "optional": true, "type": "number", "description": "Use management port as source port", "format": "flag"}, "period": {"description": "Specify the period in second", "format": "number", "type": "number", "maximum": 31536000, "minimum": 60, "optional": true}}}], "type": "array", "$ref": "/axapi/v3/export-periodic/axdebug/{axdebug}"}
    :param ssl_crl_list: {"minItems": 1, "items": {"type": "ssl-crl"}, "uniqueItems": true, "array": [{"required": ["ssl-crl"], "properties": {"period": {"description": "Specify the period in second", "format": "number", "type": "number", "maximum": 31536000, "minimum": 60, "optional": true}, "remote-file": {"optional": true, "type": "string", "description": "profile name for remote url", "format": "url"}, "use-mgmt-port": {"default": 0, "optional": true, "type": "number", "description": "Use management port as source port", "format": "flag"}, "ssl-crl": {"description": "SSL Crl File", "format": "string", "minLength": 1, "optional": false, "maxLength": 255, "type": "string"}}}], "type": "array", "$ref": "/axapi/v3/export-periodic/ssl-crl/{ssl-crl}"}
    :param ssl_cert_key_list: {"minItems": 1, "items": {"type": "ssl-cert-key"}, "uniqueItems": true, "array": [{"required": ["ssl-cert-key"], "properties": {"ssl-cert-key": {"description": "Local SSL Key/Certificate file name", "format": "string", "minLength": 1, "optional": false, "maxLength": 255, "type": "string"}, "remote-file": {"optional": true, "type": "string", "description": "profile name for remote url", "format": "url"}, "use-mgmt-port": {"default": 0, "optional": true, "type": "number", "description": "Use management port as source port", "format": "flag"}, "period": {"description": "Specify the period in second", "format": "number", "type": "number", "maximum": 31536000, "minimum": 60, "optional": true}}}], "type": "array", "$ref": "/axapi/v3/export-periodic/ssl-cert-key/{ssl-cert-key}"}
    :param debug_monitor_list: {"minItems": 1, "items": {"type": "debug-monitor"}, "uniqueItems": true, "array": [{"required": ["debug-monitor"], "properties": {"remote-file": {"optional": true, "type": "string", "description": "profile name for remote url", "format": "url"}, "debug-monitor": {"description": "Debug Monitor Output", "format": "string", "minLength": 1, "optional": false, "maxLength": 63, "type": "string"}, "use-mgmt-port": {"default": 0, "optional": true, "type": "number", "description": "Use management port as source port", "format": "flag"}, "period": {"description": "Specify the period in second", "format": "number", "type": "number", "maximum": 31536000, "minimum": 60, "optional": true}}}], "type": "array", "$ref": "/axapi/v3/export-periodic/debug-monitor/{debug-monitor}"}
    :param syslog_list: {"minItems": 1, "items": {"type": "syslog"}, "uniqueItems": true, "array": [{"required": ["syslog"], "properties": {"syslog": {"description": "Syslog file", "format": "string", "minLength": 1, "optional": false, "maxLength": 63, "type": "string"}, "remote-file": {"optional": true, "type": "string", "description": "profile name for remote url", "format": "url"}, "use-mgmt-port": {"default": 0, "optional": true, "type": "number", "description": "Use management port as source port", "format": "flag"}, "period": {"description": "Specify the period in second", "format": "number", "type": "number", "maximum": 31536000, "minimum": 60, "optional": true}}}], "type": "array", "$ref": "/axapi/v3/export-periodic/syslog/{syslog}"}
    :param auth_portal_list: {"minItems": 1, "items": {"type": "auth-portal"}, "uniqueItems": true, "array": [{"required": ["auth-portal"], "properties": {"remote-file": {"optional": true, "type": "string", "description": "profile name for remote url", "format": "url"}, "use-mgmt-port": {"default": 0, "optional": true, "type": "number", "description": "Use management port as source port", "format": "flag"}, "auth-portal": {"description": "Portal file for http authentication", "format": "string", "minLength": 1, "optional": false, "maxLength": 63, "type": "string"}, "period": {"description": "Specify the period in second", "format": "number", "type": "number", "maximum": 31536000, "minimum": 60, "optional": true}}}], "type": "array", "$ref": "/axapi/v3/export-periodic/auth-portal/{auth-portal}"}
    :param DeviceProxy: The device proxy for REST operations and session handling. Refer to `common/device_proxy.py`

    

    URL for this object::
    `https://<Hostname|Ip address>//axapi/v3/export-periodic`.

    

    
    """
    def __init__(self, **kwargs):
        self.ERROR_MSG = ""
        self.required=[]
        self.b_key = "export-periodic"
        self.a10_url="/axapi/v3/export-periodic"
        self.DeviceProxy = ""
        self.ssl_key_list = []
        self.local_uri_file_list = []
        self.ssl_cert_list = []
        self.dnssec_ds_list = []
        self.xml_schema_list = []
        self.aflex_list = []
        self.dnssec_dnskey_list = []
        self.geo_location_list = []
        self.policy_list = []
        self.class_list_list = []
        self.wsdl_list = []
        self.bw_list_list = []
        self.ip_map_list_list = []
        self.axdebug_list = []
        self.ssl_crl_list = []
        self.ssl_cert_key_list = []
        self.debug_monitor_list = []
        self.syslog_list = []
        self.auth_portal_list = []

        for keys, value in kwargs.items():
            setattr(self,keys, value)





from a10sdk.common.A10BaseClass import A10BaseClass


class Ethernet(A10BaseClass):
    
    """Class Description::
    preferred-session-sync-port ethernet.

    Class ethernet supports CRUD Operations and inherits from `common/A10BaseClass`.
    This class is the `"PARENT"` class for this module.`

    :param pre_eth: {"optional": false, "type": "number", "description": "Ethernet interface number", "format": "interface"}
    :param pre_vlan: {"description": "Interface VLAN (VLAN ID)", "format": "number", "type": "number", "maximum": 4094, "minimum": 1, "optional": true}
    :param DeviceProxy: The device proxy for REST operations and session handling. Refer to `common/device_proxy.py`

    

    URL for this object::
    `https://<Hostname|Ip address>//axapi/v3/vrrp-a/preferred-session-sync-port/ethernet/{pre_eth}`.

    

    
    """
    def __init__(self, **kwargs):
        self.ERROR_MSG = ""
        self.required = [ "pre_eth"]

        self.b_key = "ethernet"
        self.a10_url="/axapi/v3/vrrp-a/preferred-session-sync-port/ethernet/{pre_eth}"
        self.DeviceProxy = ""
        self.pre_eth = ""
        self.pre_vlan = ""

        for keys, value in kwargs.items():
            setattr(self,keys, value)





from a10sdk.common.A10BaseClass import A10BaseClass


class Global(A10BaseClass):
    
    """Class Description::
    Define the Health Monitor global default.

    Class global supports CRUD Operations and inherits from `common/A10BaseClass`.
    This class is the `"PARENT"` class for this module.`

    :param disable_auto_adjust: {"default": 0, "optional": true, "type": "number", "description": "Disable the Health Check Rate Auto Adjustment", "format": "flag"}
    :param external_rate: {"description": "Define the External Health Check Rate (Number of External Script Programs (default 2))", "format": "number", "default": 2, "optional": true, "maximum": 999, "minimum": 1, "type": "number"}
    :param multi_process: {"description": "Start Health Monitoring in Multi-Process Mode (Specify the number of multiple processes (default 1))", "format": "number", "default": 1, "optional": true, "maximum": 20, "minimum": 1, "type": "number"}
    :param interval: {"description": "Specify the Healthcheck Interval (Interval Value, in seconds (default 5))", "format": "number", "default": 5, "optional": true, "maximum": 180, "minimum": 1, "type": "number"}
    :param check_rate: {"description": "Health Check Rate per 500ms (default 1000)", "format": "number", "default": 1000, "optional": true, "maximum": 50000, "minimum": 1, "type": "number"}
    :param per: {"description": "Specify the Unit Time for the rate (Specify the Unit Time, multiple of 100ms)", "format": "number", "default": 2, "optional": true, "maximum": 20, "minimum": 1, "type": "number"}
    :param retry: {"description": "Specify the Healthcheck Retries (Retry Count (default 3))", "format": "number", "default": 3, "optional": true, "maximum": 10, "minimum": 1, "type": "number"}
    :param up_retry: {"description": "Specify the Healthcheck Retries before declaring target up (Up-retry count (default 1))", "format": "number", "default": 1, "optional": true, "maximum": 10, "minimum": 1, "type": "number"}
    :param timeout: {"description": "Specify the Healthcheck Timeout (Timeout Value, in seconds (default 5), Timeout should be less than or equal to interval)", "format": "number", "default": 5, "optional": true, "maximum": 180, "minimum": 1, "type": "number"}
    :param DeviceProxy: The device proxy for REST operations and session handling. Refer to `common/device_proxy.py`

    

    URL for this object::
    `https://<Hostname|Ip address>//axapi/v3/health/global`.

    

    
    """
    def __init__(self, **kwargs):
        self.ERROR_MSG = ""
        self.required=[]
        self.b_key = "global"
        self.a10_url="/axapi/v3/health/global"
        self.DeviceProxy = ""
        self.disable_auto_adjust = ""
        self.external_rate = ""
        self.multi_process = ""
        self.interval = ""
        self.check_rate = ""
        self.per = ""
        self.retry = ""
        self.up_retry = ""
        self.timeout = ""

        for keys, value in kwargs.items():
            setattr(self,keys, value)





from a10sdk.common.A10BaseClass import A10BaseClass


class Stats(A10BaseClass):
    
    """This class does not support CRUD Operations please use parent.

    :param stream_creation_failure: {"description": "Stream Creation Failures", "format": "counter", "type": "number", "oid": "3", "optional": true, "size": "8"}
    :param streams_created: {"description": "Streams Created", "format": "counter", "type": "number", "oid": "1", "optional": true, "size": "8"}
    :param no_session_mem: {"description": "Data Session Creation Failures", "format": "counter", "type": "number", "oid": "10", "optional": true, "size": "8"}
    :param ports_allocated: {"description": "Stream Client Ports Allocated", "format": "counter", "type": "number", "oid": "4", "optional": true, "size": "8"}
    :param port_allocation_failure: {"description": "Stream Client Port Allocation Failures", "format": "counter", "type": "number", "oid": "6", "optional": true, "size": "8"}
    :param streams_freed: {"description": "Streams Freed", "format": "counter", "type": "number", "oid": "2", "optional": true, "size": "8"}
    :param unknown_client_port_from_server: {"description": "Server Replies With Unknown Client Ports", "format": "counter", "type": "number", "oid": "7", "optional": true, "size": "8"}
    :param ports_freed: {"description": "Stream Client Ports Freed", "format": "counter", "type": "number", "oid": "5", "optional": true, "size": "8"}
    :param data_session_freed: {"description": "Data Session Freed", "format": "counter", "type": "number", "oid": "9", "optional": true, "size": "8"}
    :param data_session_created: {"description": "Data Session Created", "format": "counter", "type": "number", "oid": "8", "optional": true, "size": "8"}
    :param DeviceProxy: The device proxy for REST operations and session handling. Refer to `common/device_proxy.py`

    

    
    """
    def __init__(self, **kwargs):
        self.ERROR_MSG = ""
        
        self.b_key = "stats"
        self.DeviceProxy = ""
        self.stream_creation_failure = ""
        self.streams_created = ""
        self.no_session_mem = ""
        self.ports_allocated = ""
        self.port_allocation_failure = ""
        self.streams_freed = ""
        self.unknown_client_port_from_server = ""
        self.ports_freed = ""
        self.data_session_freed = ""
        self.data_session_created = ""

        for keys, value in kwargs.items():
            setattr(self,keys, value)


class Rtsp(A10BaseClass):
    
    """Class Description::
    Statistics for the object rtsp.

    Class rtsp supports CRUD Operations and inherits from `common/A10BaseClass`.
    This class is the `"PARENT"` class for this module.`

    :param DeviceProxy: The device proxy for REST operations and session handling. Refer to `common/device_proxy.py`

    

    URL for this object::
    `https://<Hostname|Ip address>//axapi/v3/cgnv6/fixed-nat/alg/rtsp/stats`.

    

    
    """
    def __init__(self, **kwargs):
        self.ERROR_MSG = ""
        self.required=[]
        self.b_key = "rtsp"
        self.a10_url="/axapi/v3/cgnv6/fixed-nat/alg/rtsp/stats"
        self.DeviceProxy = ""
        self.stats = {}

        for keys, value in kwargs.items():
            setattr(self,keys, value)





from a10sdk.common.A10BaseClass import A10BaseClass


class Stats(A10BaseClass):
    
    """This class does not support CRUD Operations please use parent.

    :param msg_too_big: {"description": "Log message too big", "format": "counter", "type": "number", "oid": "7", "optional": true, "size": "8"}
    :param buff_send_fail: {"description": "Buffer send fail", "format": "counter", "type": "number", "oid": "10", "optional": true, "size": "8"}
    :param remote_log_rate: {"description": "Remote rate (per sec)", "format": "counter", "type": "number", "oid": "6", "optional": true, "size": "8"}
    :param alloc_conn: {"description": "Log-session alloc", "format": "counter", "type": "number", "oid": "11", "optional": true, "size": "8"}
    :param no_repeat_msg: {"description": "No repeat message", "format": "counter", "type": "number", "oid": "14", "optional": true, "size": "8"}
    :param free_conn: {"description": "Log-session free", "format": "counter", "type": "number", "oid": "12", "optional": true, "size": "8"}
    :param conn_alloc_fail: {"description": "Log-session alloc fail", "format": "counter", "type": "number", "oid": "13", "optional": true, "size": "8"}
    :param local_log_msg: {"description": "Local log messages", "format": "counter", "type": "number", "oid": "3", "optional": true, "size": "8"}
    :param total_log_msg: {"description": "Total log messages", "format": "counter", "type": "number", "oid": "2", "optional": true, "size": "8"}
    :param no_route: {"description": "No route", "format": "counter", "type": "number", "oid": "9", "optional": true, "size": "8"}
    :param remote_log_msg: {"description": "Remote log messages", "format": "counter", "type": "number", "oid": "4", "optional": true, "size": "8"}
    :param buff_alloc_fail: {"description": "Buffer alloc fail", "format": "counter", "type": "number", "oid": "8", "optional": true, "size": "8"}
    :param local_log_rate: {"description": "Local rate (per sec)", "format": "counter", "type": "number", "oid": "5", "optional": true, "size": "8"}
    :param total_log_times: {"description": "Total log times", "format": "counter", "type": "number", "oid": "1", "optional": true, "size": "8"}
    :param DeviceProxy: The device proxy for REST operations and session handling. Refer to `common/device_proxy.py`

    

    
    """
    def __init__(self, **kwargs):
        self.ERROR_MSG = ""
        
        self.b_key = "stats"
        self.DeviceProxy = ""
        self.msg_too_big = ""
        self.buff_send_fail = ""
        self.remote_log_rate = ""
        self.alloc_conn = ""
        self.no_repeat_msg = ""
        self.free_conn = ""
        self.conn_alloc_fail = ""
        self.local_log_msg = ""
        self.total_log_msg = ""
        self.no_route = ""
        self.remote_log_msg = ""
        self.buff_alloc_fail = ""
        self.local_log_rate = ""
        self.total_log_times = ""

        for keys, value in kwargs.items():
            setattr(self,keys, value)


class RateLimitLog(A10BaseClass):
    
    """Class Description::
    Statistics for the object rate-limit-log.

    Class rate-limit-log supports CRUD Operations and inherits from `common/A10BaseClass`.
    This class is the `"PARENT"` class for this module.`

    :param DeviceProxy: The device proxy for REST operations and session handling. Refer to `common/device_proxy.py`

    

    URL for this object::
    `https://<Hostname|Ip address>//axapi/v3/slb/rate-limit-log/stats`.

    

    
    """
    def __init__(self, **kwargs):
        self.ERROR_MSG = ""
        self.required=[]
        self.b_key = "rate-limit-log"
        self.a10_url="/axapi/v3/slb/rate-limit-log/stats"
        self.DeviceProxy = ""
        self.stats = {}

        for keys, value in kwargs.items():
            setattr(self,keys, value)





from a10sdk.common.A10BaseClass import A10BaseClass


class Group(A10BaseClass):
    
    """Class Description::
    Define a User Security Model group.

    Class group supports CRUD Operations and inherits from `common/A10BaseClass`.
    This class is the `"PARENT"` class for this module.`

    :param read: {"description": "specify a read view for the group (read view name)", "format": "string", "minLength": 1, "optional": true, "maxLength": 31, "type": "string"}
    :param groupname: {"description": "Name of the group", "format": "string", "minLength": 1, "optional": false, "maxLength": 31, "type": "string"}
    :param v3: {"optional": true, "enum": ["auth", "noauth", "priv"], "type": "string", "description": "'auth': group using the authNoPriv Security Level; 'noauth': group using the noAuthNoPriv Security Level; 'priv': group using SNMPv3 authPriv security level; ", "format": "enum"}
    :param DeviceProxy: The device proxy for REST operations and session handling. Refer to `common/device_proxy.py`

    

    URL for this object::
    `https://<Hostname|Ip address>//axapi/v3/snmp-server/group/{groupname}`.

    

    
    """
    def __init__(self, **kwargs):
        self.ERROR_MSG = ""
        self.required = [ "groupname"]

        self.b_key = "group"
        self.a10_url="/axapi/v3/snmp-server/group/{groupname}"
        self.DeviceProxy = ""
        self.read = ""
        self.groupname = ""
        self.v3 = ""

        for keys, value in kwargs.items():
            setattr(self,keys, value)





from a10sdk.common.A10BaseClass import A10BaseClass


class Stats(A10BaseClass):
    
    """This class does not support CRUD Operations please use parent.

    :param nat_resp: {"description": "(NAT) No. of responses", "format": "counter", "type": "number", "oid": "8", "optional": true, "size": "2"}
    :param slb_resp_no_match: {"description": "No. of requests with no response", "format": "counter", "type": "number", "oid": "5", "optional": true, "size": "2"}
    :param nat_xid_reused: {"description": "(NAT) No. of requests reusing a transaction id", "format": "counter", "type": "number", "oid": "13", "optional": true, "size": "2"}
    :param slb_req: {"description": "No. of requests", "format": "counter", "type": "number", "oid": "1", "optional": true, "size": "2"}
    :param slb_no_resp: {"description": "No. of resource failures", "format": "counter", "type": "number", "oid": "3", "optional": true, "size": "2"}
    :param nat_req: {"description": "(NAT) No. of requests", "format": "counter", "type": "number", "oid": "7", "optional": true, "size": "2"}
    :param slb_req_rexmit: {"description": "No. of request retransmits", "format": "counter", "type": "number", "oid": "4", "optional": true, "size": "2"}
    :param nat_no_resource: {"description": "(NAT) No. of resource failures", "format": "counter", "type": "number", "oid": "12", "optional": true, "size": "2"}
    :param nat_no_resp: {"description": "(NAT) No. of resource failures", "format": "counter", "type": "number", "oid": "9", "optional": true, "size": "2"}
    :param nat_req_rexmit: {"description": "(NAT) No. of request retransmits", "format": "counter", "type": "number", "oid": "10", "optional": true, "size": "2"}
    :param nat_resp_no_match: {"description": "(NAT) No. of requests with no response", "format": "counter", "type": "number", "oid": "11", "optional": true, "size": "2"}
    :param slb_no_resource: {"description": "No. of resource failures", "format": "counter", "type": "number", "oid": "6", "optional": true, "size": "2"}
    :param slb_resp: {"description": "No. of responses", "format": "counter", "type": "number", "oid": "2", "optional": true, "size": "2"}
    :param DeviceProxy: The device proxy for REST operations and session handling. Refer to `common/device_proxy.py`

    

    
    """
    def __init__(self, **kwargs):
        self.ERROR_MSG = ""
        
        self.b_key = "stats"
        self.DeviceProxy = ""
        self.nat_resp = ""
        self.slb_resp_no_match = ""
        self.nat_xid_reused = ""
        self.slb_req = ""
        self.slb_no_resp = ""
        self.nat_req = ""
        self.slb_req_rexmit = ""
        self.nat_no_resource = ""
        self.nat_no_resp = ""
        self.nat_req_rexmit = ""
        self.nat_resp_no_match = ""
        self.slb_no_resource = ""
        self.slb_resp = ""

        for keys, value in kwargs.items():
            setattr(self,keys, value)


class Dns(A10BaseClass):
    
    """Class Description::
    Statistics for the object dns.

    Class dns supports CRUD Operations and inherits from `common/A10BaseClass`.
    This class is the `"PARENT"` class for this module.`

    :param DeviceProxy: The device proxy for REST operations and session handling. Refer to `common/device_proxy.py`

    

    URL for this object::
    `https://<Hostname|Ip address>//axapi/v3/slb/dns/stats`.

    

    
    """
    def __init__(self, **kwargs):
        self.ERROR_MSG = ""
        self.required=[]
        self.b_key = "dns"
        self.a10_url="/axapi/v3/slb/dns/stats"
        self.DeviceProxy = ""
        self.stats = {}

        for keys, value in kwargs.items():
            setattr(self,keys, value)





from a10sdk.common.A10BaseClass import A10BaseClass


class GeoLocation(A10BaseClass):
    
    """    :param all: {"description": "Delete all files", "format": "flag", "default": 0, "optional": true, "not": "filename", "type": "number"}
    :param filename: {"description": "Specify file to be deleted", "format": "string", "minLength": 1, "optional": true, "maxLength": 63, "not": "all", "type": "string"}
    :param DeviceProxy: The device proxy for REST operations and session handling. Refer to `common/device_proxy.py`

Class Description::
    Delete geo-location file.

    Class geo-location supports CRUD Operations and inherits from `common/A10BaseClass`.
    This class is the `"PARENT"` class for this module.`

    

    URL for this object::
    `https://<Hostname|Ip address>//axapi/v3/delete/geo-location`.

    

    
    """
    def __init__(self, **kwargs):
        self.ERROR_MSG = ""
        self.required=[]
        self.b_key = "geo-location"
        self.a10_url="/axapi/v3/delete/geo-location"
        self.DeviceProxy = ""
        self.A10WW_all = ""
        self.filename = ""

        for keys, value in kwargs.items():
            setattr(self,keys, value)





from a10sdk.common.A10BaseClass import A10BaseClass


class Dns(A10BaseClass):
    
    """Class Description::
    DNS Global Options.

    Class dns supports CRUD Operations and inherits from `common/A10BaseClass`.
    This class is the `"PARENT"` class for this module.`

    :param action: {"description": "'none': No action (default); 'drop': Drop query; 'reject': Send refuse response; 'ignore': Send empty response; ", "format": "enum", "default": "none", "type": "string", "enum": ["none", "drop", "reject", "ignore"], "optional": true}
    :param logging: {"description": "'none': No logging (default); 'query': DNS Query; 'response': DNS Response; 'both': Both DNS Query and Response; ", "format": "enum", "default": "none", "type": "string", "enum": ["none", "query", "response", "both"], "optional": true}
    :param DeviceProxy: The device proxy for REST operations and session handling. Refer to `common/device_proxy.py`

    

    URL for this object::
    `https://<Hostname|Ip address>//axapi/v3/gslb/dns`.

    

    
    """
    def __init__(self, **kwargs):
        self.ERROR_MSG = ""
        self.required=[]
        self.b_key = "dns"
        self.a10_url="/axapi/v3/gslb/dns"
        self.DeviceProxy = ""
        self.action = ""
        self.logging = ""

        for keys, value in kwargs.items():
            setattr(self,keys, value)





from a10sdk.common.A10BaseClass import A10BaseClass


class Pmtu(A10BaseClass):
    
    """Class Description::
    Configure Path MTU option.

    Class pmtu supports CRUD Operations and inherits from `common/A10BaseClass`.
    This class is the `"PARENT"` class for this module.`

    :param action: {"description": "\"disable\": Disable IPv6 PMTU processing; \"enable\": Enable IPv6 PMTU processing; ", "format": "enum", "default": "disable", "type": "string", "enum": ["disable", "enable"], "optional": true}
    :param timeout: {"description": "Path MTU timeout to restore the original value (Path MTU timeout of the aggregated route (Default: 300 secs)).", "format": "number", "type": "number", "maximum": 900, "minimum": 120, "optional": true}
    :param DeviceProxy: The device proxy for REST operations and session handling. Refer to `common/device_proxy.py`

    

    URL for this object::
    `https://<Hostname|Ip address>//axapi/v3/ipv6/pmtu`.

    

    
    """
    def __init__(self, **kwargs):
        self.ERROR_MSG = ""
        self.required=[]
        self.b_key = "pmtu"
        self.a10_url="/axapi/v3/ipv6/pmtu"
        self.DeviceProxy = ""
        self.action = ""
        self.timeout = ""

        for keys, value in kwargs.items():
            setattr(self,keys, value)





from a10sdk.common.A10BaseClass import A10BaseClass


class IpNatRedist(A10BaseClass):
    
    """Class Description::
    IP NAT redistribution.

    Class ip-nat-redist supports CRUD Operations and inherits from `common/A10BaseClass`.
    This class is the `"PARENT"` class for this module.`

    :param metric_ip_nat: {"description": "OSPF default metric. help-val OSPF metric", "format": "number", "type": "number", "maximum": 16777214, "minimum": 0, "optional": true}
    :param route_map_ip_nat: {"description": "Route map reference. help-val Pointer to route-map entries", "format": "string", "minLength": 1, "optional": true, "maxLength": 128, "type": "string"}
    :param tag_ip_nat: {"optional": true, "type": "number", "description": "Set tag for routes redistributed into OSPF. help-val 32-bit tag value", "format": "number"}
    :param metric_type_ip_nat: {"description": "1: \"Set OSPF External Type 1 metrics\"; 2: \"Set OSPF External Type 2 metrics\"; ", "format": "enum", "default": "2", "type": "string", "enum": ["1", "2"], "optional": true}
    :param DeviceProxy: The device proxy for REST operations and session handling. Refer to `common/device_proxy.py`

    

    URL for this object::
    `https://<Hostname|Ip address>//axapi/v3/router/ospf/{process_id}/redistribute/ip-nat/ip-nat-redist`.

    

    
    """
    def __init__(self, **kwargs):
        self.ERROR_MSG = ""
        self.required=[]
        self.b_key = "ip-nat-redist"
        self.a10_url="/axapi/v3/router/ospf/{process_id}/redistribute/ip-nat/ip-nat-redist"
        self.DeviceProxy = ""
        self.metric_ip_nat = ""
        self.route_map_ip_nat = ""
        self.tag_ip_nat = ""
        self.metric_type_ip_nat = ""

        for keys, value in kwargs.items():
            setattr(self,keys, value)





from a10sdk.common.A10BaseClass import A10BaseClass


class AlternateServer(A10BaseClass):
    
    """This class does not support CRUD Operations please use parent.

    :param alternate_name: {"minLength": 1, "maxLength": 127, "type": "string", "description": "Alternate Name", "format": "string-rlx"}
    :param alternate: {"description": "Alternate Server (Alternate Server Number)", "minimum": 1, "type": "number", "maximum": 16, "format": "number"}
    :param DeviceProxy: The device proxy for REST operations and session handling. Refer to `common/device_proxy.py`

    

    
    """
    def __init__(self, **kwargs):
        self.ERROR_MSG = ""
        
        self.b_key = "alternate-server"
        self.DeviceProxy = ""
        self.alternate_name = ""
        self.alternate = ""

        for keys, value in kwargs.items():
            setattr(self,keys, value)


class Server(A10BaseClass):
    
    """Class Description::
    Server.

    Class server supports CRUD Operations and inherits from `common/A10BaseClass`.
    This class is the `"PARENT"` class for this module.`

    :param conn_resume: {"description": "Connection Resume (Connection Resume (min active conn before resume taking new conn))", "format": "number", "type": "number", "maximum": 1000000, "minimum": 1, "optional": true}
    :param health_check_disable: {"description": "Disable configured health check configuration", "format": "flag", "default": 0, "optional": true, "not": "health-check", "type": "number"}
    :param extended_stats: {"default": 0, "optional": true, "type": "number", "description": "Enable extended statistics on real server", "format": "flag"}
    :param stats_data_action: {"description": "'stats-data-enable': Enable statistical data collection for real server; 'stats-data-disable': Disable statistical data collection for real server; ", "format": "enum", "default": "stats-data-enable", "type": "string", "enum": ["stats-data-enable", "stats-data-disable"], "optional": true}
    :param name: {"description": "Server Name", "format": "string-rlx", "minLength": 1, "optional": false, "maxLength": 127, "type": "string"}
    :param weight: {"description": "Weight for this Real Server (Connection Weight)", "format": "number", "default": 1, "optional": true, "maximum": 100, "minimum": 1, "type": "number"}
    :param fqdn_name: {"description": "Server hostname", "format": "string", "minLength": 1, "modify-not-allowed": 1, "optional": true, "maxLength": 63, "type": "string"}
    :param spoofing_cache: {"default": 0, "optional": true, "type": "number", "description": "This server is a spoofing cache", "format": "flag"}
    :param alternate_server: {"minItems": 1, "items": {"type": "object"}, "uniqueItems": true, "type": "array", "array": [{"properties": {"alternate-name": {"minLength": 1, "maxLength": 127, "type": "string", "description": "Alternate Name", "format": "string-rlx"}, "alternate": {"description": "Alternate Server (Alternate Server Number)", "minimum": 1, "type": "number", "maximum": 16, "format": "number"}, "optional": true}}]}
    :param conn_limit: {"description": "Connection Limit", "format": "number", "default": 8000000, "optional": true, "maximum": 8000000, "minimum": 1, "type": "number"}
    :param external_ip: {"optional": true, "type": "string", "description": "External IP address for NAT of GSLB", "format": "ipv4-address"}
    :param host: {"optional": true, "modify-not-allowed": 1, "type": "string", "description": "IP Address", "format": "ipv4-address"}
    :param port_list: {"minItems": 1, "items": {"type": "port"}, "uniqueItems": true, "array": [{"required": ["port-number", "protocol"], "properties": {"conn-limit": {"description": "Connection Limit", "format": "number", "default": 8000000, "optional": true, "maximum": 8000000, "minimum": 1, "type": "number"}, "health-check-disable": {"description": "Disable health check", "format": "flag", "default": 0, "optional": true, "not-list": ["health-check", "health-check-follow-port"], "type": "number"}, "extended-stats": {"default": 0, "optional": true, "type": "number", "description": "Enable extended statistics on real server port", "format": "flag"}, "template-server-ssl": {"description": "Server side SSL template (Server side SSL Name)", "format": "string", "minLength": 1, "optional": true, "maxLength": 63, "type": "string", "$ref": "/axapi/v3/slb/template/server-ssl"}, "weight": {"description": "Port Weight (Connection Weight)", "format": "number", "default": 1, "optional": true, "maximum": 100, "minimum": 1, "type": "number"}, "conn-resume": {"description": "Connection Resume", "format": "number", "type": "number", "maximum": 1000000, "minimum": 1, "optional": true}, "alternate-port": {"minItems": 1, "items": {"type": "object"}, "uniqueItems": true, "type": "array", "array": [{"properties": {"alternate-name": {"minLength": 1, "maxLength": 127, "type": "string", "description": "Alternate Name", "format": "string-rlx"}, "alternate-server-port": {"description": "Port (Alternate Server Port Value)", "minimum": 1, "type": "number", "maximum": 65535, "format": "number"}, "alternate": {"description": "Alternate Server Number", "minimum": 1, "type": "number", "maximum": 16, "format": "number"}, "optional": true}}]}, "no-logging": {"default": 0, "optional": true, "type": "number", "description": "Do not log connection over limit event", "format": "flag"}, "stats-data-action": {"description": "'stats-data-enable': Enable statistical data collection for real server port; 'stats-data-disable': Disable statistical data collection for real server port; ", "format": "enum", "default": "stats-data-enable", "type": "string", "enum": ["stats-data-enable", "stats-data-disable"], "optional": true}, "follow-port-protocol": {"optional": true, "enum": ["tcp", "udp"], "type": "string", "description": "'tcp': TCP Port; 'udp': UDP Port; ", "format": "enum"}, "port-number": {"description": "Port Number", "format": "number", "type": "number", "maximum": 65534, "minimum": 0, "optional": false}, "range": {"description": "Port range (Port range value - used for vip-to-rport-mapping)", "format": "number", "default": 0, "optional": true, "maximum": 254, "minimum": 0, "type": "number"}, "no-ssl": {"default": 0, "optional": true, "type": "number", "description": "No SSL", "format": "flag"}, "auth-cfg": {"type": "object", "properties": {"service-principal-name": {"minLength": 1, "maxLength": 128, "type": "string", "description": "Service Principal Name (Kerberos principal name)", "format": "string-rlx"}}}, "action": {"description": "'enable': enable; 'disable': disable; ", "format": "enum", "default": "enable", "type": "string", "enum": ["enable", "disable"], "optional": true}, "protocol": {"optional": false, "enum": ["tcp", "udp"], "type": "string", "description": "'tcp': TCP Port; 'udp': UDP Port; ", "format": "enum"}, "health-check-follow-port": {"description": "Specify which port to follow for health status (Port Number)", "format": "number", "optional": true, "not-list": ["health-check", "health-check-disable"], "maximum": 65534, "minimum": 1, "type": "number"}, "health-check": {"description": "Health Check (Monitor Name)", "format": "string", "minLength": 1, "not-list": ["health-check-follow-port", "health-check-disable"], "optional": true, "maxLength": 31, "type": "string", "$ref": "/axapi/v3/health/monitor"}, "template-port": {"description": "Port template (Port template name)", "format": "string", "default": "default", "minLength": 1, "optional": true, "maxLength": 63, "type": "string", "$ref": "/axapi/v3/slb/template/port"}}}], "type": "array", "$ref": "/axapi/v3/slb/server/{name}/port/{port-number}+{protocol}"}
    :param slow_start: {"default": 0, "optional": true, "type": "number", "description": "Slowly ramp up the connection number after server is up (start from 128, then double every 10 sec till 4096)", "format": "flag"}
    :param ipv6: {"optional": true, "type": "string", "description": "IPv6 address Mapping of GSLB", "format": "ipv6-address"}
    :param action: {"description": "'enable': Enable this Real Server; 'disable': Disable this Real Server; ", "format": "enum", "default": "enable", "type": "string", "enum": ["enable", "disable"], "optional": true}
    :param template_server: {"description": "Server template (Server template name)", "format": "string", "default": "default", "minLength": 1, "optional": true, "maxLength": 32, "type": "string", "$ref": "/axapi/v3/slb/template/server"}
    :param server_ipv6_addr: {"optional": true, "modify-not-allowed": 1, "type": "string", "description": "IPV6 address", "format": "ipv6-address"}
    :param health_check: {"description": "Health Check Monitor (Health monitor name)", "format": "string", "minLength": 1, "optional": true, "maxLength": 31, "not": "health-check-disable", "type": "string", "$ref": "/axapi/v3/health/monitor"}
    :param no_logging: {"default": 0, "optional": true, "type": "number", "description": "Do not log connection over limit event", "format": "flag"}
    :param DeviceProxy: The device proxy for REST operations and session handling. Refer to `common/device_proxy.py`

    

    URL for this object::
    `https://<Hostname|Ip address>//axapi/v3/slb/server/{name}`.

    

    
    """
    def __init__(self, **kwargs):
        self.ERROR_MSG = ""
        self.required = [ "name"]

        self.b_key = "server"
        self.a10_url="/axapi/v3/slb/server/{name}"
        self.DeviceProxy = ""
        self.conn_resume = ""
        self.health_check_disable = ""
        self.extended_stats = ""
        self.stats_data_action = ""
        self.name = ""
        self.weight = ""
        self.fqdn_name = ""
        self.spoofing_cache = ""
        self.alternate_server = []
        self.conn_limit = ""
        self.external_ip = ""
        self.host = ""
        self.port_list = []
        self.slow_start = ""
        self.ipv6 = ""
        self.action = ""
        self.template_server = ""
        self.server_ipv6_addr = ""
        self.health_check = ""
        self.no_logging = ""

        for keys, value in kwargs.items():
            setattr(self,keys, value)





from a10sdk.common.A10BaseClass import A10BaseClass


class IcmpTimeout(A10BaseClass):
    
    """This class does not support CRUD Operations please use parent.

    :param icmp_timeout_val: {"description": "Timeout in seconds (Interval of 60 seconds)", "minimum": 2, "type": "number", "maximum": 15000, "format": "number"}
    :param icmp_timeout: {"default": "fast", "enum": ["age", "fast"], "type": "string", "description": "'age': Expiration time; 'fast': Use Fast aging; ", "format": "enum"}
    :param DeviceProxy: The device proxy for REST operations and session handling. Refer to `common/device_proxy.py`

    

    
    """
    def __init__(self, **kwargs):
        self.ERROR_MSG = ""
        
        self.b_key = "icmp-timeout"
        self.DeviceProxy = ""
        self.icmp_timeout_val = ""
        self.icmp_timeout = ""

        for keys, value in kwargs.items():
            setattr(self,keys, value)


class Translation(A10BaseClass):
    
    """Class Description::
    Change or Disable NAT translation values.

    Class translation supports CRUD Operations and inherits from `common/A10BaseClass`.
    This class is the `"PARENT"` class for this module.`

    :param tcp_timeout: {"description": "TCP protocol extended translations (Timeout in seconds (Interval of 60 seconds), default is 300 seconds (5 minutes))", "format": "number", "default": 300, "optional": true, "maximum": 15000, "minimum": 2, "type": "number"}
    :param service_timeout_list: {"minItems": 1, "items": {"type": "service-timeout"}, "uniqueItems": true, "array": [{"required": ["service-type", "port"], "properties": {"timeout-val": {"description": "Timeout in seconds (Interval of 60 seconds)", "format": "number", "type": "number", "maximum": 15000, "minimum": 2, "optional": true}, "service-type": {"optional": false, "enum": ["tcp", "udp"], "type": "string", "description": "'tcp': TCP Protocol; 'udp': UDP Protocol; ", "format": "enum"}, "timeout-type": {"optional": true, "enum": ["age", "fast"], "type": "string", "description": "'age': Expiration time; 'fast': Use Fast aging; ", "format": "enum"}, "port": {"description": "Port Number", "format": "number", "type": "number", "maximum": 65535, "minimum": 1, "optional": false}}}], "type": "array", "$ref": "/axapi/v3/ip/nat/translation/service-timeout/{service-type}+{port}"}
    :param udp_timeout: {"description": "UDP protocol extended translations (Timeout in seconds (Interval of 60 seconds), default is 300 seconds (5 minutes))", "format": "number", "default": 300, "optional": true, "maximum": 15000, "minimum": 2, "type": "number"}
    :param DeviceProxy: The device proxy for REST operations and session handling. Refer to `common/device_proxy.py`

    

    URL for this object::
    `https://<Hostname|Ip address>//axapi/v3/ip/nat/translation`.

    

    
    """
    def __init__(self, **kwargs):
        self.ERROR_MSG = ""
        self.required=[]
        self.b_key = "translation"
        self.a10_url="/axapi/v3/ip/nat/translation"
        self.DeviceProxy = ""
        self.tcp_timeout = ""
        self.service_timeout_list = []
        self.udp_timeout = ""
        self.icmp_timeout = {}

        for keys, value in kwargs.items():
            setattr(self,keys, value)


